@@ -22,6 +22,8 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skginterfaceplugin.h"
+#include "ui_skgbookmarkpluginwidget_pref.h"
+
 #include <QObject>
 #include <QVariantList>
 #include <kgenericfactory.h>
@@ -59,6 +61,18 @@ public:
      */
     virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument);
 
+    /**
+     * The preference widget of the plugin.
+     * @return The preference widget of the plugin
+     */
+    virtual QWidget* getPreferenceWidget();
+
+    /**
+     * The preference skeleton of the plugin.
+     * @return The preference skeleton of the plugin
+     */
+    virtual KConfigSkeleton* getPreferenceSkeleton();
+
     /**
      * Must be modified to refresh widgets after a modification.
      */
@@ -70,6 +84,12 @@ public:
      */
     virtual QString title() const;
 
+    /**
+     * The icon of the plugin.
+     * @return The icon of the plugin
+     */
+    virtual QString icon() const;    
+
     /**
      * The tips list of the plugin.
      * @return The tips list of the plugin
@@ -105,6 +125,8 @@ private:
 
     KToolBarPopupAction* m_bookmarkAction;
     KMenu* m_bookmarkMenu;
+
+    Ui::skgbookmarkplugin_pref ui;
 };
 
 #endif // SKGDEBUGPLUGIN_H
