@@ -20,6 +20,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgbookmarkplugindockwidget.h"
+#include "skgbookmark_settings.h"
 #include "skgtraces.h"
 #include "skgdocument.h"
 #include "skgobjectmodelbase.h"
@@ -184,7 +185,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
 }
 
 
-void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool iFirstInNewPage)
+void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool iFirstInNewPage, bool iPin)
 {
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::openBookmark");
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -211,7 +212,8 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
             //This bookmark has information ==> we open it
             SKGTabPage* page = SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(data[0]), tabNumberForNextOpen, data[2], selectedNode.getName(), SKGServices::intToString(selectedNode.getID()), i == nodes.count() - 1);
             if (page) {
-                SKGTabWidget* tab = dynamic_cast<SKGTabWidget*>(SKGMainPanel::getMainPanel()->centralWidget());
+                if (skgbookmark_settings::pinhomebookmarks()) page->setPin(iPin);
+                SKGTabWidget* tab = SKGMainPanel::getMainPanel()->getTabWidget();
                 if (tab) tab->setTabIcon(SKGMainPanel::getMainPanel()->currentPageIndex(), selectedNode.getIcon());
                 selectedNode.opened = true;
                 tabNumberForNextOpen = -1;
