@@ -55,8 +55,9 @@ public:
      * Open a bookmark
      * @param iNode bookmark object to open
      * @param iFirstInNewPage to open first object in new page
+     * @param iPin to pin opened page
      */
-    static void openBookmark(const SKGNodeObject& iNode, bool iFirstInNewPage = false);
+    static void openBookmark(const SKGNodeObject& iNode, bool iFirstInNewPage = false, bool iPin = false);
 
 protected:
     /**
