@@ -63,7 +63,7 @@ bool SKGDebugPlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
     actionCollection()->addAction(QLatin1String("debug_restart_profiling"), restartProfiling);
     restartProfiling->setShortcut(Qt::CTRL + Qt::Key_Pause);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("debug_reVerbstart_profiling", restartProfiling);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("debug_reVerbstart_profiling", restartProfiling);
 
     QStringList overlayopen;
     overlayopen.push_back("skg_open");
@@ -72,7 +72,7 @@ bool SKGDebugPlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
     actionCollection()->addAction(QLatin1String("debug_open_profiling"), openProfiling);
     openProfiling->setShortcut(Qt::ALT + Qt::Key_Pause);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("debug_open_profiling", openProfiling);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("debug_open_profiling", openProfiling);
     return true;
 }
 
