@@ -70,7 +70,7 @@ bool SKGDeletePlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     actionCollection()->addAction(QLatin1String("edit_delete"), m_deleteAction);
     m_deleteAction->setShortcut(Qt::Key_Delete);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_delete", m_deleteAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_delete", m_deleteAction);
     return true;
 }
 
