@@ -261,7 +261,7 @@ void SKGFilePlugin::actionNew()
     if (SKGMainPanel::getMainPanel() && m_currentDocument && SKGMainPanel::getMainPanel()->queryFileClose()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-        SKGMainPanel::getMainPanel()->closeAllPages();
+        SKGMainPanel::getMainPanel()->closeAllPages(true);
 
         err = m_currentDocument->initialize();
 
@@ -270,8 +270,8 @@ void SKGFilePlugin::actionNew()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after creating a Skrooge document", "Document successfully created."));
-        else err.addError(ERR_FAIL, i18nc("Error message: Could not create a Skrooge document",  "Document creation failed."));
+        if (!err) err = SKGError(0, i18nc("Successful message after creating a document", "Document successfully created."));
+        else err.addError(ERR_FAIL, i18nc("Error message: Could not create a document",  "Document creation failed."));
 
         //Display error
         SKGMainPanel::displayErrorMessage(err);
@@ -308,7 +308,7 @@ void SKGFilePlugin::actionSaveAs()
     SKGTRACEINRC(10, "SKGFilePlugin::actionSaveAs", err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///" % m_currentDocument->objectName(),
-                           "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .skg --> Skrooge document", "%1 document", KCmdLineArgs::aboutData()->programName()) ,
+                           "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .csv --> CSV document", "%1 document", KCmdLineArgs::aboutData()->programName()) ,
                            SKGMainPanel::getMainPanel());
         if (fileName.isEmpty()) return;
 
@@ -349,7 +349,7 @@ void SKGFilePlugin::actionOpen(const KUrl& iUrl)
         QString programName = KCmdLineArgs::aboutData()->programName();
         QString fileName = iUrl.pathOrUrl();
         if (fileName.isEmpty()) fileName = KFileDialog::getOpenUrl(KUrl("kfiledialog:///" % m_currentDocument->objectName()),
-                                               "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .skg --> Skrooge document", "%1 document", programName) ,
+                                               "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .csv --> CSV document", "%1 document", programName) ,
                                                SKGMainPanel::getMainPanel()).pathOrUrl();
         if (!fileName.isEmpty()) {
             //Check if temporary file exists
@@ -366,7 +366,7 @@ void SKGFilePlugin::actionOpen(const KUrl& iUrl)
 
             //Open
             QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-            SKGMainPanel::getMainPanel()->closeAllPages();
+            SKGMainPanel::getMainPanel()->closeAllPages(true);
             err = m_currentDocument->load(fileName, "", restoreTmpFile);
             QApplication::restoreOverrideCursor();
 
