@@ -60,7 +60,7 @@ bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     setXMLFile("../skg_highlight/skg_highlight.rc");
 
     //------------
-    m_switchHighLight = new KAction(KIcon("rating"), i18nc("Verb", "Switch highlight"), this);
+    m_switchHighLight = new KAction(KIcon("bookmarks"), i18nc("Verb", "Switch highlight"), this);
     connect(m_switchHighLight, SIGNAL(triggered(bool)), this, SLOT(actionSwitchHighLight()));
     actionCollection()->addAction(QLatin1String("edit_switch_highlight"), m_switchHighLight);
     m_switchHighLight->setShortcut(Qt::CTRL + Qt::Key_H);
@@ -92,7 +92,7 @@ QString SKGHighlightPlugin::title() const
 
 QString SKGHighlightPlugin::icon() const
 {
-    return "rating";
+    return "bookmarks";
 }
 
 QString SKGHighlightPlugin::toolTip() const
