@@ -155,11 +155,11 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
             int fromPage = qMin(iPrinter->fromPage(), iPrinter->toPage());
             int toPage = qMax(iPrinter->fromPage(), iPrinter->toPage());
 
-            KTabWidget* tabs = (KTabWidget*) SKGMainPanel::getMainPanel()->centralWidget();
+            SKGTabWidget* tabs = SKGMainPanel::getMainPanel()->getTabWidget();
 
             //Compute the number of pages
             QList<QWidget*> pages;
-            int nbtabs = tabs->count();
+            int nbtabs = tabs ? tabs->count() : 0;
             for (int i = 0; i < nbtabs; ++i) {
                 //Yes, get the widget
                 SKGTabPage* page = (SKGTabPage*) tabs->widget(i);
