@@ -232,10 +232,11 @@ SKGAdviceList SKGUndoRedoPlugin::advices() const
 
 SKGError SKGUndoRedoPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
 {
+    SKGError err;
     if (m_currentDocument && iAdviceIdentifier == "skgundoredoplugin_too_big") {
         if (iSolution == 0) {
             QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-            SKGError err = m_currentDocument->removeAllTransactions();
+            err = m_currentDocument->removeAllTransactions();
             QApplication::restoreOverrideCursor();
 
             //status bar
@@ -245,7 +246,7 @@ SKGError SKGUndoRedoPlugin::executeAdviceCorrection(const QString& iAdviceIdenti
             //Display error
             SKGMainPanel::displayErrorMessage(err);
         } else SKGMainPanel::getMainPanel()->optionsPreferences(this->objectName());
-        return SKGError();
+        return err;
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
 }
