@@ -153,7 +153,7 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
     if (iCSVMapping == NULL) {
         //Automatic build
         //Open file
-        QFile file(m_importer->getFileName());
+        QFile file(m_importer->getLocalFileName());
         if (!file.open(QIODevice::ReadOnly)) {
             err.setReturnCode(ERR_INVALIDARG);
             err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
@@ -204,7 +204,7 @@ SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
     if (iIndex == -1) {
         //Automatic build
         //Open file
-        QFile file(m_importer->getFileName());
+        QFile file(m_importer->getLocalFileName());
         if (!file.open(QIODevice::ReadOnly)) {
             err.setReturnCode(ERR_INVALIDARG);
             err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
@@ -253,9 +253,6 @@ SKGError SKGImportPluginCsv::importFile()
 
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginCsv::importFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
-
     //Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "CSV"), 3);
     if (!err) {
@@ -275,10 +272,10 @@ SKGError SKGImportPluginCsv::importFile()
 
         //Open file
         if (!err) {
-            QFile file(iFileName);
+            QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                 err.setReturnCode(ERR_INVALIDARG);
-                err.setMessage(i18nc("Error message",  "Open file '%1' failed", iFileName));
+                err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
             } else {
                 QTextStream stream(&file);
                 if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -347,7 +344,7 @@ SKGError SKGImportPluginCsv::importFile()
                     err.setMessage(i18nc("Error message",  "Date format not supported"));
                 }
                 if (!err)
-                    err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", iFileName, m_importer->getCodec(), dateFormat));
+                    err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName(), m_importer->getCodec(), dateFormat));
 
                 //Step 2 done
                 if (!err) err = m_importer->getDocument()->stepForward(2);
@@ -601,14 +598,12 @@ SKGError SKGImportPluginCsv::exportFile()
     if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     SKGError err;
     SKGTRACEINRC(2, "SKGImportCsv::exportFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     //Open file
-    KSaveFile file(iFileName);
+    KSaveFile file(m_importer->getLocalFileName());
     if (!file.open()) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Save file '%1' failed", iFileName));
+        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName()));
     } else {
         QTextStream out(&file);
         if (!m_importer->getCodec().isEmpty()) out.setCodec(m_importer->getCodec().toAscii().constData());
@@ -636,7 +631,6 @@ SKGError SKGImportPluginCsv::importCSVUnit()
 {
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginCsv::importCSVUnit", err);
-    SKGTRACEL(10) << "Input filename=" << m_importer->getFileName() << endl;
 
     if (m_importer->getDocument()) {
         //Begin transaction
@@ -657,7 +651,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
 
             //Open file
             if (!err) {
-                QFile file(m_importer->getFileName());
+                QFile file(m_importer->getLocalFileName());
                 if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                     err.setReturnCode(ERR_INVALIDARG);
                     err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
