@@ -102,7 +102,12 @@ SKGError SKGImportPluginGnc::importFile()
 
             ////Get book
             QDomElement book = docElem.firstChildElement("gnc:book");
-            if (!book.isNull()) {
+            if (book.isNull()) {
+                book = docElem;
+            }
+            if (book.isNull()) {
+                err = SKGError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName()));
+            } else {
                 QMap<QString, SKGUnitObject> mapUnitIdUnit;
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GNC"), 6);
                 if (!err) {
