@@ -66,12 +66,10 @@ SKGError SKGImportPluginMmb::importFile()
     if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     SKGError err;
     SKGTRACEINRC(2, "SKGImportMmb::importFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     {
         QSqlDatabase originalDocument(QSqlDatabase::addDatabase("QSQLITE", "originalDocument"));
-        originalDocument.setDatabaseName(iFileName);
+        originalDocument.setDatabaseName(m_importer->getLocalFileName());
         if (!originalDocument.open()) {
             //Set error message
             QSqlError sqlErr = originalDocument.lastError();
