@@ -116,11 +116,12 @@ SKGError SKGImportPluginMT940::importFile()
                                 QString name = "MT940";
                                 QString number = name;
                                 if (vals.count() == 2) {
-                                    name = vals.at(0);
+                                    bankName = vals.at(0);
                                     number = vals.at(1);
+                                    name = number;
                                 } else if (vals.count() == 1) {
-                                    name = vals.at(0);
                                     number = vals.at(0);
+                                    name = number;
                                 }
 
                                 //Search if account is already existing
