@@ -66,7 +66,12 @@ SKGError SKGImportPluginOfx::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginOfx::importFile", err);
 
-    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX"));
+    if (!QFile(m_importer->getLocalFileName()).exists()) {
+        err.setReturnCode(ERR_INVALIDARG);
+        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+    }
+
+    if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX"));
     if (!err) {
         SKGImportPluginOfx::m_ofxError = SKGError();
         SKGImportPluginOfx::m_ofxInitialBalance.clear();
