@@ -68,8 +68,6 @@ SKGError SKGImportPluginQif::importFile()
 
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginQif::importFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     //Info for QIF format:
     //http://mb-net.net/Debian/src/gnucash/gnucash-2.2.6/src/import-export/qif-import/file-format.txt
@@ -86,10 +84,10 @@ SKGError SKGImportPluginQif::importFile()
         if (!err) err = m_importer->getDocument()->stepForward(1);
 
         //Open file
-        QFile file(iFileName);
+        QFile file(m_importer->getLocalFileName());
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", iFileName));
+            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -139,7 +137,7 @@ SKGError SKGImportPluginQif::importFile()
                 err.setMessage(i18nc("Error message",  "Date format not supported"));
             }
             if (!err)
-                err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", iFileName, m_importer->getCodec(), dateFormat));
+                err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName(), m_importer->getCodec(), dateFormat));
 
             //Step 2 done
             if (!err) err = m_importer->getDocument()->stepForward(2);
@@ -231,8 +229,6 @@ SKGError SKGImportPluginQif::importFile()
                             SKGCategoryObject Category;
                             val.replace('/', OBJECTSEPARATOR);
                             val.replace(':', OBJECTSEPARATOR);
-                            val.replace(',', OBJECTSEPARATOR);
-                            val.replace(';', OBJECTSEPARATOR);
                             err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), val, Category);
                         }
                     } else if (inSection == 'A') {
@@ -778,14 +774,12 @@ SKGError SKGImportPluginQif::exportFile()
     if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     SKGError err;
     SKGTRACEINRC(2, "SKGImportQif::exportFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     //Open file
-    KSaveFile file(iFileName);
+    KSaveFile file(m_importer->getLocalFileName());
     if (!file.open()) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Save file '%1' failed", iFileName));
+        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName()));
     } else {
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
