@@ -42,7 +42,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(SKGDocument* iDocument)
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    m_menuFavorite = new KAction(KIcon("rating"), i18nc("Display only favorite accounts", "Highlighted only"), this);
+    m_menuFavorite = new KAction(KIcon("bookmarks"), i18nc("Display only favorite accounts", "Highlighted only"), this);
     m_menuFavorite->setCheckable(true);
     m_menuFavorite->setChecked(false);
     connect(m_menuFavorite, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
