@@ -53,7 +53,12 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     if (reportPlugin) {
         m_graph = qobject_cast< SKGWidget* >(reportPlugin->getDashboardWidget(0));
         if (m_graph) {
-            ui.verticalLayout->insertWidget(2, m_graph);
+            //To avoid hidden page when no account exist
+            QWidget* w = new QWidget(this);
+            QVBoxLayout* verticalLayout = new QVBoxLayout(w);
+            verticalLayout->addWidget(m_graph);
+
+            ui.verticalLayout->insertWidget(2, w);
             //Set initial state
             m_graph->hide();
 
@@ -106,13 +111,13 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitEdit->setDocument(iDocument);
 
     //Set show widget
-    ui.kView->getShowWidget()->addItem("opened", i18n("Opened"), "", "t_close='N'", "", "highlighted", "closed", "");
-    ui.kView->getShowWidget()->addItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'", "", "highlighted", "opened", "");
-    ui.kView->getShowWidget()->addSeparator();
-    ui.kView->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "rating", "t_bookmarked='Y'", "", "opened;closed", "opened");
+    ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
+    ui.kView->getShowWidget()->addGroupedItem("opened", i18n("Opened"), "", "t_close='N'");
+    ui.kView->getShowWidget()->addGroupedItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'");
+    ui.kView->getShowWidget()->addGroupedItem("highlighted", i18n("Highlighted only"), "bookmarks", "t_bookmarked='Y'");
     if (m_graph) {
         ui.kView->getShowWidget()->addSeparator();
-        ui.kView->getShowWidget()->addItem("graph", i18n("Graph"), "view-investment", "1=0", "", "", "");
+        ui.kView->getShowWidget()->addItem("graph", i18n("Graph"), "view-investment", "1=0");
     }
 
     ui.kView->getShowWidget()->setDefaultState("opened");
@@ -267,7 +272,10 @@ void SKGBankPluginWidget::onSelectionChanged()
         SKGUnitObject oUnit;
         account.getInitialBalance(oBalance, oUnit);
 
-        ui.kAmountEdit->setText(KGlobal::locale()->formatMoney(oBalance, "", 2));
+        int nbDec = oUnit.getNumberDecimal();
+        if (nbDec == 0) nbDec = 2;
+
+        ui.kAmountEdit->setText(KGlobal::locale()->formatMoney(oBalance, "", nbDec));
         if (oUnit.exist()) {
             ui.kUnitEdit->setUnit(oUnit);
         } else {
@@ -452,7 +460,7 @@ void SKGBankPluginWidget::onAddAccountClicked()
             if (!err) err = accountObj.setComment(ui.kAccountCreatorComment->text());
             if (!err) err = accountObj.setNumber(ui.kAccountCreatorNumber->text());
             if (!err) err = accountObj.setType(accountType);
-            if (!err) err = accountObj.save(false);
+            if (!err) err = accountObj.save();
             if (!err) err = setInitialBalanceFromEditor(accountObj);
             if (!err) err = accountObj.save();
         }
