@@ -136,9 +136,12 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
 
     //Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
+        ui.kView->getView()->insertGlobalAction();
+        ui.kView->getView()->insertGlobalAction("open");
+        ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("edit_delete");
     }
-    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onDoubleClick()));
+    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
     //Add Standard KDE Icons to buttons to Operations
@@ -488,7 +491,7 @@ SKGError SKGBudgetPluginWidget::updateBudgetRule(SKGBudgetRuleObject& iRule)
     if (!err) err = iRule.save();
     return err;
 }
-void SKGBudgetPluginWidget::open(const SKGBudgetObject& iBudget)
+void SKGBudgetPluginWidget::open(const SKGBudgetObject& iBudget) //TODO: use open of operations
 {
     _SKGTRACEIN(10, "SKGBudgetPluginWidget::open");
 
@@ -531,19 +534,6 @@ void SKGBudgetPluginWidget::open(const SKGBudgetObject& iBudget)
     }
 }
 
-void SKGBudgetPluginWidget::onDoubleClick()
-{
-    _SKGTRACEIN(10, "SKGBudgetPluginWidget::onDoubleClick");
-    if (!m_objectModel) return;
-
-    //Get selection
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
-    if (selection.count() == 1 && m_objectModel->getRealTable() == "budget") {
-        SKGBudgetObject budget(selection.at(0));
-        SKGBudgetPluginWidget::open(budget);
-    }
-}
-
 void SKGBudgetPluginWidget::onCreatorModified()
 {
     bool test = !ui.kAmountEdit->text().isEmpty() && !ui.kYear->text().isEmpty();
