@@ -54,10 +54,10 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     ui.kAdd->setIcon(KIcon("list-add"));
 
     ui.kLoadSummaryTitle->setPixmap(KIcon("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kPaymentSummaryTitle->setPixmap(KIcon("rating").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kPaymentSummaryTitle->setPixmap(KIcon("bookmarks").pixmap(22, 22), KTitleWidget::ImageLeft);
     ui.kAmortizationTableTitle->setPixmap(KIcon("view-pim-calendar").pixmap(22, 22), KTitleWidget::ImageLeft);
 
-    ui.kInterestResultsTitle->setPixmap(KIcon("rating").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kInterestResultsTitle->setPixmap(KIcon("bookmarks").pixmap(22, 22), KTitleWidget::ImageLeft);
     ui.kInterestValuesTitle->setPixmap(KIcon("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
     ui.kDefineValueTitle->setPixmap(KIcon("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
 
