@@ -46,10 +46,10 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
     ui.setupUi(this);
 
     //Set show widget
-    ui.kCategoriesView->getShowWidget()->addItem("all", i18n("All"), "", "", "", "expenditure;highlighted;income", "highlighted");
-    ui.kCategoriesView->getShowWidget()->addItem("income", i18n("Income only"), "list-add", "f_REALCURRENTAMOUNT>=0", "", "all;expenditure;highlighted", "all");
-    ui.kCategoriesView->getShowWidget()->addItem("expenditure", i18n("Expenditure only"), "list-remove", "f_REALCURRENTAMOUNT<=0", "", "all;income;highlighted", "all");
-    ui.kCategoriesView->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "rating", "t_HASBOOKMARKEDCHILD<>'N'", "", "all;income;expenditure", "all");
+    ui.kCategoriesView->getShowWidget()->addGroupedItem("all", i18n("All"));
+    ui.kCategoriesView->getShowWidget()->addGroupedItem("income", i18n("Income"), "list-add", "f_REALCURRENTAMOUNT>=0");
+    ui.kCategoriesView->getShowWidget()->addGroupedItem("expenditure", i18n("Expenditure"), "list-remove", "f_REALCURRENTAMOUNT<=0");
+    ui.kCategoriesView->getShowWidget()->addGroupedItem("highlighted", i18n("Highlighted"), "bookmarks", "t_HASBOOKMARKEDCHILD<>'N'");
     ui.kCategoriesView->getShowWidget()->setDefaultState("all");
 
     ui.kAdd->setMaximumWidth(ui.kAdd->height());
@@ -237,8 +237,7 @@ void SKGCategoriesPluginWidget::onAddCategory()
     SKGError err;
     _SKGTRACEINRC(10, "SKGCategoriesPluginWidget::onAddCategory", err);
     SKGCategoryObject cat;
-    QString name;
-    if (getNbSelectedObjects() == 0) name = ui.kNameInput1->text();
+    QString name = ui.kNameInput1->text();
     if (name.isEmpty()) name = i18nc("Noun, default name for a new category", "New category");
     {
         //Get Selection
