@@ -108,7 +108,7 @@ void SKGBookmarkBoardWidget::onOpen(const QString& iLink)
 
         root.setAttribute("operationWhereClause", "id=" % iLink);
         root.setAttribute("title", i18nc("Noun, a list of items", "Highlighted operations"));
-        root.setAttribute("title_icon", "rating");
+        root.setAttribute("title_icon", "bookmarks");
     }
     SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
 }
