@@ -29,6 +29,7 @@
 #include <QDomDocument>
 
 #include <kaction.h>
+#include <kcolorscheme.h>
 
 SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     : SKGWidget(iDocument)
@@ -42,6 +43,16 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     ui.kIncome_previousLabel->setText("<a href=\"IP\">" % ui.kIncome_previousLabel->text() % "</a>");
     ui.kExpense_previousLabel->setText("<a href=\"EP\">" % ui.kExpense_previousLabel->text() % "</a>");
 
+    //Define color style
+    KColorScheme scheme(QPalette::Normal);
+    QString negative = scheme.foreground(KColorScheme::NegativeText).color().name();
+    QString neutral = scheme.foreground(KColorScheme::NeutralText).color().name();
+    QString positive = scheme.foreground(KColorScheme::PositiveText).color().name();
+
+    m_negativeStyleSheet = QString(" QProgressBar { text-align: center; padding: 0.5px;} QProgressBar::chunk {text-align: center; border-radius:4px; background-color: ") % negative % ";}" % ui.kIncome->styleSheet();
+    m_neutralStyleSheet = QString(" QProgressBar { text-align: center; padding: 0.5px;} QProgressBar::chunk {text-align: center; border-radius:4px; background-color: ") % neutral % ";}" % ui.kIncome->styleSheet();
+    m_positiveStyleSheet = QString(" QProgressBar { text-align: center; padding: 0.5px;} QProgressBar::chunk {text-align: center; border-radius:4px; background-color: ") % positive % ";}" % ui.kIncome->styleSheet();
+
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
@@ -170,9 +181,7 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                 ui.kExpense->setValue(expense_month);
                 ui.kExpense_previous->setValue(expense_previous_month);
                 ui.kSaving->setValue(qAbs(income_month - expense_month));
-                ui.kSaving->setInvertedAppearance(expense_month > income_month);
                 ui.kSaving_previous->setValue(qAbs(income_previous_month - expense_previous_month));
-                ui.kSaving_previous->setInvertedAppearance(expense_previous_month > income_previous_month);
 
                 //Set texts and tool tips
                 ui.kIncome->setFormat(doc->formatMoney(income_month, primary, false));
@@ -189,6 +198,14 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                     ui.kSaving->setToolTip(doc->formatMoney(income_month - expense_month, secondary, false));
                     ui.kSaving_previous->setToolTip(doc->formatMoney(income_previous_month - expense_previous_month, secondary, false));
                 }
+
+                //Change colors
+                ui.kIncome->setStyleSheet(m_positiveStyleSheet);
+                ui.kIncome_previous->setStyleSheet(m_positiveStyleSheet);
+                ui.kExpense->setStyleSheet(m_negativeStyleSheet);
+                ui.kExpense_previous->setStyleSheet(m_negativeStyleSheet);
+                ui.kSaving->setStyleSheet(income_month - expense_month < 0 ? m_negativeStyleSheet : income_month - expense_month < 0.1 * income_month ? m_neutralStyleSheet : m_positiveStyleSheet);
+                ui.kSaving_previous->setStyleSheet(income_previous_month - expense_previous_month < 0 ? m_negativeStyleSheet : income_previous_month - expense_previous_month < 0.1 * income_previous_month ? m_neutralStyleSheet : m_positiveStyleSheet);
             }
 
             //No widget if no account
