@@ -130,7 +130,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("open", m_open);
 
-    m_openHighLights = new KAction(KIcon("rating", NULL, overlayopen), i18nc("Verb", "Open highlights..."), this);
+    m_openHighLights = new KAction(KIcon("bookmarks", NULL, overlayopen), i18nc("Verb", "Open highlights..."), this);
     connect(m_openHighLights, SIGNAL(triggered(bool)), this, SLOT(actionOpenHighLights()));
     actionCollection()->addAction(QLatin1String("view_open_highlight"), m_openHighLights);
     m_openHighLights->setShortcut(Qt::META + Qt::Key_H);
@@ -609,12 +609,13 @@ void SKGOperationPlugin::actionOpenOperations()
                         title += ',';
                     }
 
-                    wc += "(EXISTS(SELECT 1 FROM recurrentoperation s WHERE s.rd_operation_id=v_operation_display_all.id and s.id=" % SKGServices::intToString(tmp.getID()) % ") OR r_recurrentoperation_id=" % SKGServices::intToString(tmp.getID()) + ')';
+                    wc += "(EXISTS(SELECT 1 FROM recurrentoperation s WHERE s.rd_operation_id=v_operation_display.id and s.id=" % SKGServices::intToString(tmp.getID()) % ") OR r_recurrentoperation_id=" % SKGServices::intToString(tmp.getID()) + ')';
                     title += i18n("'%1'", tmp.getDisplayName());
                 }
 
                 //Set icon
                 icon = "chronometer";
+                view = "v_operation_display";
             } else if (table == "rule") {
                 title = i18nc("Noun, a list of items", "Sub operations corresponding to rule:");
 
@@ -663,23 +664,33 @@ void SKGOperationPlugin::actionOpenOperations()
                 icon = "view-financial-list";
             }
 
-            //Call operation plugin
-            QDomDocument doc("SKGML");
-            doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(view != "v_operation_consolidated" ? "SKGOPERATION_DEFAULT_PARAMETERS" : "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
-            QDomElement root = doc.documentElement();
-            if (root.isNull()) {
-                root = doc.createElement("parameters");
+            //Open
+            if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
+                //Call debug plugin
+                QDomDocument doc("SKGML");
+                QDomElement root = doc.createElement("parameters");
                 doc.appendChild(root);
+                root.setAttribute("sqlOrder", "SELECT * from " % (view.isEmpty() ? "v_operation_display" : view) % " WHERE " % wc);
+
+                SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
+            } else {
+                QDomDocument doc("SKGML");
+                doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(view != "v_operation_consolidated" ? "SKGOPERATION_DEFAULT_PARAMETERS" : "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
+                QDomElement root = doc.documentElement();
+                if (root.isNull()) {
+                    root = doc.createElement("parameters");
+                    doc.appendChild(root);
+                }
+
+                if (!view.isEmpty()) root.setAttribute("operationTable", view);
+                if (!wc.isEmpty()) root.setAttribute("operationWhereClause", wc);
+                if (!title.isEmpty()) root.setAttribute("title", title);
+                if (!icon.isEmpty()) root.setAttribute("title_icon", icon);
+                if (!account.isEmpty()) root.setAttribute("account", account);
+                else root.setAttribute("currentPage", "-1");
+
+                SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
             }
-
-            if (!view.isEmpty()) root.setAttribute("operationTable", view);
-            if (!wc.isEmpty()) root.setAttribute("operationWhereClause", wc);
-            if (!title.isEmpty()) root.setAttribute("title", title);
-            if (!icon.isEmpty()) root.setAttribute("title_icon", icon);
-            if (!account.isEmpty()) root.setAttribute("account", account);
-            else root.setAttribute("currentPage", "-1");
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
         }
     }
 }
@@ -702,7 +713,7 @@ void SKGOperationPlugin::openHighLights()
 
     root.setAttribute("operationWhereClause", wc);
     root.setAttribute("title", title);
-    root.setAttribute("title_icon", "rating");
+    root.setAttribute("title_icon", "bookmarks");
 
     if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
 }
@@ -818,7 +829,7 @@ SKGAdviceList SKGOperationPlugin::advices() const
 
     //Check operations without category
     bool exist = false;
-    m_currentBankDocument->existObjects("v_operation_display", "EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)", exist);
+    m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='N' AND EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)", exist);
     if (exist) {
         SKGAdvice ad;
         ad.setUUID("skgoperationplugin_nocategory");
@@ -831,8 +842,21 @@ SKGAdviceList SKGOperationPlugin::advices() const
         output.push_back(ad);
     }
 
+    m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='Y' AND EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)", exist);
+    if (exist) {
+        SKGAdvice ad;
+        ad.setUUID("skgoperationplugin_transfer_nocategory");
+        ad.setPriority(3);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many transfers don't have category"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget to associate a category for each transfer."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open transfers without category"));
+        ad.setAutoCorrections(autoCorrections);
+        output.push_back(ad);
+    }
+
     //Check operations without payee
-    m_currentBankDocument->existObjects("v_operation_display", "r_payee_id=0", exist);
+    m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='N' AND r_payee_id=0", exist);
     if (exist) {
         SKGAdvice ad;
         ad.setUUID("skgoperationplugin_nopayee");
@@ -845,6 +869,19 @@ SKGAdviceList SKGOperationPlugin::advices() const
         output.push_back(ad);
     }
 
+    m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='Y' AND r_payee_id=0", exist);
+    if (exist) {
+        SKGAdvice ad;
+        ad.setUUID("skgoperationplugin_transfer_nopayee");
+        ad.setPriority(3);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many transfers don't have payee"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget to associate a payee for each transfer."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open transfers without payee"));
+        ad.setAutoCorrections(autoCorrections);
+        output.push_back(ad);
+    }
+
     //Check operations in group of only one transaction
     m_currentBankDocument->existObjects("v_operation_display", "i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=v_operation_display.i_group_id)<2", exist);
     if (exist) {
@@ -928,9 +965,6 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
         SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier == "skgoperationplugin_nocategory") {
-        //Get parameters
-        QString account = iAdviceIdentifier.right(iAdviceIdentifier.length() - 36);
-
         //Call operation plugin
         QDomDocument doc("SKGML");
         doc.setContent(m_currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
@@ -940,11 +974,26 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             doc.appendChild(root);
         }
 
-        root.setAttribute("operationWhereClause", "EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)");
+        root.setAttribute("operationWhereClause", "t_TRANSFER='N' AND EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)");
         root.setAttribute("title", i18nc("Noun, a list of items", "Operations without category"));
         root.setAttribute("title_icon", "skrooge_category");
         SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
         return SKGError();
+    } else if (m_currentBankDocument && iAdviceIdentifier == "skgoperationplugin_transfer_nocategory") {
+        //Call operation plugin
+        QDomDocument doc("SKGML");
+        doc.setContent(m_currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
+        QDomElement root = doc.documentElement();
+        if (root.isNull()) {
+            root = doc.createElement("parameters");
+            doc.appendChild(root);
+        }
+
+        root.setAttribute("operationWhereClause", "t_TRANSFER='Y' AND EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)");
+        root.setAttribute("title", i18nc("Noun, a list of items", "Transfers without category"));
+        root.setAttribute("title_icon", "skrooge_category");
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+        return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier == "skgoperationplugin_groupofone") {
         if (iSolution == 0) {
             //Call operation plugin
@@ -976,9 +1025,6 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             SKGMainPanel::displayErrorMessage(err);
         }
     } else if (m_currentBankDocument && iAdviceIdentifier == "skgoperationplugin_nopayee") {
-        //Get parameters
-        QString account = iAdviceIdentifier.right(iAdviceIdentifier.length() - 36);
-
         //Call operation plugin
         QDomDocument doc("SKGML");
         doc.setContent(m_currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
@@ -988,11 +1034,26 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             doc.appendChild(root);
         }
 
-        root.setAttribute("operationWhereClause", "r_payee_id=0");
+        root.setAttribute("operationWhereClause", "t_TRANSFER='N' AND r_payee_id=0");
         root.setAttribute("title", i18nc("Noun, a list of items", "Operations without payee"));
         root.setAttribute("title_icon", "skrooge_payee");
         SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
         return SKGError();
+    } else if (m_currentBankDocument && iAdviceIdentifier == "skgoperationplugin_transfer_nopayee") {
+        //Call operation plugin
+        QDomDocument doc("SKGML");
+        doc.setContent(m_currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
+        QDomElement root = doc.documentElement();
+        if (root.isNull()) {
+            root = doc.createElement("parameters");
+            doc.appendChild(root);
+        }
+
+        root.setAttribute("operationWhereClause", "t_TRANSFER='Y' AND r_payee_id=0");
+        root.setAttribute("title", i18nc("Noun, a list of items", "Transfers without payee"));
+        root.setAttribute("title_icon", "skrooge_payee");
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+        return SKGError();
     }
 
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
