@@ -173,6 +173,7 @@ private Q_SLOTS:
     void actionOpenHighLights();
     void actionOpenLastModified();
     void actionOpenSubOperations();
+    void actionOpenOperations();
     void actionOpenDuplicate();
     void actionGroupOperation();
     void actionUngroupOperation();
@@ -191,6 +192,7 @@ private:
     KAction* m_groupOperation;
     KAction* m_ungroupOperation;
     KAction* m_mergeOperationAction;
+    KAction* m_open;
 
     SKGDocumentBank* m_currentBankDocument;
 
