@@ -397,7 +397,13 @@ void SKGOperationPluginWidget::onSelectionChanged()
         QString number = obj.getAttribute("i_number");
         if (number == "0") number = "";
         ui.kNumberEdit->setText(number);
-        ui.kAccountEdit->setText(obj.getAttribute("t_ACCOUNT"));
+        QString accountName = obj.getAttribute("t_ACCOUNT");
+        if (!m_showClosedAccounts && !ui.kAccountEdit->contains(accountName)) {
+            //Refresh list of accounts if a closed account is selected
+            m_showClosedAccounts = true;
+            dataModified("", 0);
+        }
+        ui.kAccountEdit->setText(accountName);
         ui.kPayeeEdit->setText(obj.getAttribute("t_PAYEE"));
         ui.kTypeEdit->setText(obj.getAttribute("t_mode"));
         QString unit = obj.getAttribute("t_UNIT");
@@ -409,7 +415,10 @@ void SKGOperationPluginWidget::onSelectionChanged()
         QString quantity = obj.getAttribute("f_REALQUANTITY");
         if (quantity.isEmpty()) quantity = obj.getAttribute("f_QUANTITY");
         double quantityVal = SKGServices::stringToDouble(quantity);
-        quantity = KGlobal::locale()->formatMoney(qAbs(quantityVal), "", 2);
+        SKGUnitObject unitObject = ui.kUnitEdit->getUnit();
+        int nbDec = unitObject.getNumberDecimal();
+        if (nbDec == 0) nbDec = 2;
+        quantity = KGlobal::locale()->formatMoney(qAbs(quantityVal), "", nbDec);
         if (quantity.startsWith(KGlobal::locale()->positiveSign())) quantity = quantity.right(quantity.length() - KGlobal::locale()->positiveSign().length());
         if (quantityVal > 0) quantity = '+' % quantity;
         else quantity = '-' % quantity;
@@ -452,6 +461,12 @@ void SKGOperationPluginWidget::onSelectionChanged()
                     //yes it is a transfer
                     SKGAccountObject account2;
                     op2.getParentAccount(account2);
+                    QString accountName = account2.getName();
+                    if (!m_showClosedAccounts && !ui.kTargetAccountEdit->contains(accountName)) {
+                        //Refresh list of accounts if a closed account is selected
+                        m_showClosedAccounts = true;
+                        dataModified("", 0);
+                    }
                     ui.kTargetAccountEdit->setText(account2.getName());
                     if (mode >= 0) ui.kWidgetSelector->setSelectedMode(2);
                 } else {
@@ -1102,7 +1117,10 @@ void SKGOperationPluginWidget::setState(const QString& iState)
 
     //Default values in case of reset
     if (currentPage.isEmpty()) currentPage = '0';
-    if (operationTable.isEmpty()) operationTable = "v_operation_display_all";
+    if (operationTable.isEmpty()) {
+        if (m_operationWhereClause.isEmpty()) operationTable = "v_operation_display_all";
+        else operationTable = "v_operation_display";
+    }
 
     //Set
     SKGAccountObject acc;
@@ -1149,7 +1167,16 @@ void SKGOperationPluginWidget::setState(const QString& iState)
 
     //!!! Must be done here after onFilterChanged
     ui.kOperationView->setState(root.attribute("view"));
-    if (!account.isEmpty()) ui.kOperationView->getShowWidget()->setState("##_" % account.remove(';') % ";operations;hide");
+    if (!account.isEmpty()) {
+        QStringList parameters = SKGServices::splitCSVLine(ui.kOperationView->getShowWidget()->getState());
+        if (parameters.count() == 0) {
+            parameters.push_back("");
+            parameters.push_back("operations");
+            parameters.push_back("hide");
+        }
+        parameters[0] = "##_" % account.remove(';');
+        ui.kOperationView->getShowWidget()->setState(parameters.join(";"));
+    }
 
     if (!selection.isEmpty()) {
         QStringList uuids = SKGServices::splitCSVLine(selection);
@@ -1215,8 +1242,7 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
                 //Set show widget
                 show->clear();
 
-                show->addItem("all", i18nc("Option to for display of operations", "All"), "", "1=1");
-                show->addSeparator();
+                show->addGroupedItem("all", i18nc("Option to for display of operations", "All"), "", "1=1", "account");
                 QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                 QString uncheck;
                 for (int i = 1; i < nbAccounts; ++i) { //Ignore header
@@ -1227,7 +1253,7 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
                     ui.kAccountEdit->addItem(icon, text);
                     ui.kPaymentAccountEdit->addItem(icon, text);
 
-                    show->addItem(id, text, iconName, "t_ACCOUNT='" + SKGServices::stringToSqlString(text) + '\'', "", "", "all");
+                    show->addGroupedItem(id, text, iconName, "t_ACCOUNT='" + SKGServices::stringToSqlString(text) + '\'', "account");
 
                     if (!uncheck.isEmpty()) uncheck = uncheck % ";";
                     uncheck = uncheck % id;
@@ -1240,16 +1266,16 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
                 show->setListIdToUncheckWhenChecked(0, uncheck);
 
                 show->addSeparator();
-                show->addItem("operations", i18nc("Option to for display of operations", "Operations"), "view-financial-list", "d_date!='0000-00-00' AND t_template='N'",
-                              "", "templates", "templates");
-                show->addItem("templates", i18nc("Option to for display of operations", "Templates"), "skrooge_template", "d_date!='0000-00-00' AND t_template='Y'",
-                              "", "operations", "operations");
+                show->addGroupedItem("operations", i18nc("Option to for display of operations", "Operations"), "view-financial-list", "d_date!='0000-00-00' AND t_template='N'",
+                                     "type");
+                show->addGroupedItem("templates", i18nc("Option to for display of operations", "Templates"), "skrooge_template", "d_date!='0000-00-00' AND t_template='Y'",
+                                     "type");
                 show->addSeparator();
-                show->addItem("hide", i18nc("Option to for display of operations", "Hide all checked operations"), "dialog-ok", "t_status<>'Y'",
-                              "", "hide;hide6m;hide3m;hide1y");
-                show->addItem("hide3m", i18nc("Option to for display of operations", "Hide checked operations > 3 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-3 month')", "", "hide;hide6m;hide3m;hide1y");
-                show->addItem("hide6m", i18nc("Option to for display of operations", "Hide checked operations > 6 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-6 month')", "", "hide;hide6m;hide3m;hide1y");
-                show->addItem("hide1y", i18nc("Option to for display of operations", "Hide checked operations > 1 year"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 year')", "", "hide;hide6m;hide3m;hide1y");
+                show->addGroupedItem("hide", i18nc("Option to for display of operations", "All"), "dialog-ok", "1=1", "checked");
+                show->addGroupedItem("hide", i18nc("Option to for display of operations", "Hide all checked operations"), "dialog-ok", "t_status<>'Y'", "checked");
+                show->addGroupedItem("hide3m", i18nc("Option to for display of operations", "Hide checked operations > 3 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-3 month')", "checked");
+                show->addGroupedItem("hide6m", i18nc("Option to for display of operations", "Hide checked operations > 6 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-6 month')", "checked");
+                show->addGroupedItem("hide1y", i18nc("Option to for display of operations", "Hide checked operations > 1 year"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 year')", "checked");
                 show->setMode(SKGShow::AND);
                 if (currentState.isEmpty()) {
                     show->setDefaultState("all;operations;hide");
@@ -1612,12 +1638,13 @@ void SKGOperationPluginWidget::onFocusChanged()
                 ui.kCommentEdit->hasFocus() ||
                 ui.kPayeeEdit->hasFocus()
                 ;
-    if (m_fastEditionAction) m_fastEditionAction->setEnabled(test);
+    if (m_fastEditionAction && SKGMainPanel::getMainPanel()->currentPage() == this) m_fastEditionAction->setEnabled(test);
 }
 
 void SKGOperationPluginWidget::onFastEdition()
 {
-    SKGTRACEIN(10, "SKGOperationPluginWidget::onFocusChanged");
+    if (SKGMainPanel::getMainPanel()->currentPage() != this) return;
+    SKGTRACEIN(10, "SKGOperationPluginWidget::onFastEdition");
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     SKGError err;
 
@@ -1744,7 +1771,6 @@ void SKGOperationPluginWidget::onFastEdition()
 
     //Display error
     SKGMainPanel::displayErrorMessage(err);
-
 }
 
 bool SKGOperationPluginWidget::isTemplateMode()
@@ -2013,7 +2039,8 @@ void SKGOperationPluginWidget::onAddFakeOperation()
         if (!err) err = accountObj.addOperation(op);
         if (!err) err = op.setDate(QDate::currentDate());
         if (!err) err = op.setComment(i18nc("Noun, default comment for a fake operation", "Fake operation"));
-        SKGUnitObject unit = ui.kUnitEdit->getUnit();
+        SKGUnitObject unit ;
+        if (!err) err = accountObj.getUnit(unit);
         if (!err) err = op.setUnit(unit);
         if (!err) err = op.save();
 
