@@ -41,10 +41,10 @@ SKGPayeePluginWidget::SKGPayeePluginWidget(SKGDocument* iDocument)
     ui.setupUi(this);
 
     //Set show widget
-    ui.kView->getShowWidget()->addItem("all", i18n("All"), "", "", "", "expenditure;highlighted;income", "highlighted");
-    ui.kView->getShowWidget()->addItem("income", i18n("Income only"), "list-add", "f_CURRENTAMOUNT>=0", "", "all;expenditure;highlighted", "all");
-    ui.kView->getShowWidget()->addItem("expenditure", i18n("Expenditure only"), "list-remove", "f_CURRENTAMOUNT<=0", "", "all;income;highlighted", "all");
-    ui.kView->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "rating", "t_bookmarked='Y'", "", "all;income;expenditure", "all");
+    ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
+    ui.kView->getShowWidget()->addGroupedItem("income", i18n("Income"), "list-add", "f_CURRENTAMOUNT>=0");
+    ui.kView->getShowWidget()->addGroupedItem("expenditure", i18n("Expenditure"), "list-remove", "f_CURRENTAMOUNT<=0");
+    ui.kView->getShowWidget()->addGroupedItem("highlighted", i18n("Highlighted"), "bookmarks", "t_bookmarked='Y'");
     ui.kView->getShowWidget()->setDefaultState("all");
 
     ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay("t_name")));
