@@ -70,6 +70,8 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     // FIXME: Icons are not related to the text...
     ui.kMode->addItem(KIcon("office-chart-pie"), i18nc("Display graph values as the sum of operations amount", "Sum of operations"), 0);
     ui.kMode->addItem(KIcon("office-chart-line"), i18nc("Display graph values as the cumulated sum of operations amount", "Cumulated sum of operations"), 1);
+    ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in base 100", "Base 100"), 7);
+    ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in base 100", "Cumulated sum in base 100"), 8);
     ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percent of columns"), 2);
     ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Absolute percent of columns"), 5);
     ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percent of lines"), 4);
@@ -841,7 +843,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
     QSqlDatabase* db = getDocument()->getDatabase();
     setEnabled(db != NULL);
     //Check if needed
-    if (db != NULL && (iTableName == "operation" || iTableName.isEmpty())) {
+    if (db != NULL && (iTableName == "v_operation_consolidated" || iTableName.isEmpty())) {
         SKGError err;
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
@@ -890,7 +892,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 int mode = ui.kMode->itemData(ui.kMode->currentIndex()).toInt();
 
                 //Mode history ?
-                bool modeHistory = (mode == 1);
+                bool modeHistory = (mode == 1 || mode == 8);
 
                 //Get condition (must be done before forecast on scheduled operations)
                 int nbVirtualColumn = 0;
@@ -1011,6 +1013,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 
                 if (!err) err = doc->getConsolidatedView(tableName, attCol, attLine, "f_REALCURRENTAMOUNT" % coef,
                                     (mode == 3 ? "COUNT" : "TOTAL"), condition, table);
+                int nbLines = table.count();
                 IFSKGTRACEL(10) {
                     QStringList dump = SKGServices::tableToDump(table, SKGServices::DUMP_TEXT);
                     int nbl = dump.count();
@@ -1024,22 +1027,24 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     doc->endTransaction(false);
 
                     //Compute nb date in futur
-                    QStringList line1 = table.at(0);
-                    int nbCol = line1.count();
-                    for (int i = 0; i < nbCol; ++i) {
-                        QString title = line1.at(i);
-                        if (title.endsWith(QLatin1String("999"))) {
-                            title = title.left(title.count() - 3);
-                            line1.replace(i, title);
-                            ++nbVirtualColumn;
+                    if (nbLines) {
+                        QStringList line1 = table.at(0);
+                        int nbCol = line1.count();
+                        for (int i = 0; i < nbCol; ++i) {
+                            QString title = line1.at(i);
+                            if (title.endsWith(QLatin1String("999"))) {
+                                title = title.left(title.count() - 3);
+                                line1.replace(i, title);
+                                ++nbVirtualColumn;
+                            }
                         }
+                        table.replace(0, line1);
                     }
-                    table.replace(0, line1);
                 }
 
                 if (!err) {
                     //Update title
-                    if (table.count()) {
+                    if (nbLines) {
                         //Change title
                         QStringList line1 = table.at(0);
                         if (line1.count()) {
@@ -1049,7 +1054,6 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     }
 
                     //Compute forecast on average
-                    int nbLines = table.count();
                     if (nbLines && (forecastMode == 2 || forecastMode == 3)) {
                         QStringList newLine = table.at(0);
                         int nbVals = newLine.count() - 1;
@@ -1240,6 +1244,11 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         table = SKGServices::getPercentTable(table, (mode == 2 || mode == 5), (mode == 5 || mode == 6));
                     }
 
+                    //Mode base 100
+                    if (mode == 7 || mode == 8) {
+                        table = SKGServices::getBase100Table(table);
+                    }
+
                     //Mode Count
                     if (mode == 3) {
                         primaryUnit.Symbol = ' ';
