@@ -43,9 +43,10 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
     ui.setupUi(this);
 
     //Set show widget
-    ui.kView->getShowWidget()->addItem("ongoing", i18n("Ongoing"), "", "t_times='N' OR i_nb_times>0", "", "", "finished", "");
-    ui.kView->getShowWidget()->addItem("finished", i18n("Finished"), "dialog-close", "t_times='Y' AND i_nb_times=0", "", "", "ongoing", "");
-    ui.kView->getShowWidget()->setDefaultState("ongoing;finished");
+    ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
+    ui.kView->getShowWidget()->addGroupedItem("ongoing", i18n("Ongoing"), "task-ongoing", "t_times='N' OR i_nb_times>0");
+    ui.kView->getShowWidget()->addGroupedItem("finished", i18n("Complete"), "task-complete", "t_times='Y' AND i_nb_times=0");
+    ui.kView->getShowWidget()->setDefaultState("all");
 
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_recurrentoperation_display", "", this, "", false));
 
@@ -169,8 +170,8 @@ void SKGScheduledPluginWidget::onJumpToTheOperation()
                 doc.appendChild(root);
             }
 
+            root.setAttribute("operationTable", "v_operation_display_all");
             root.setAttribute("operationWhereClause", wc);
-            root.setAttribute("currentPage", "1");
             root.setAttribute("selection", op.getUniqueID());
             root.setAttribute("title", title);
             root.setAttribute("title_icon", "chronometer");
