@@ -94,7 +94,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     connect(m_executeAll, SIGNAL(triggered(bool)), SLOT(execute()));
     actionCollection()->addAction(QLatin1String("execute_all"), m_executeAll);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("execute_all", m_executeAll);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("execute_all", m_executeAll);
 
     //Execute on imported operation
     {
@@ -104,7 +104,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
         connect(m_executeImported, SIGNAL(triggered(bool)), SLOT(execute()));
         actionCollection()->addAction(QLatin1String("execute_imported"), m_executeImported);
 
-        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("execute_imported", m_executeImported);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("execute_imported", m_executeImported);
     }
 
     //Execute on not validated
@@ -115,13 +115,13 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
         connect(m_executeNotValidated, SIGNAL(triggered(bool)), SLOT(execute()));
         actionCollection()->addAction(QLatin1String("execute_not_validated"), m_executeNotValidated);
 
-        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("execute_not_validated", m_executeNotValidated);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("execute_not_validated", m_executeNotValidated);
     }
 
     //Search
     m_searchAction = actionCollection()->addAction(KStandardAction::Find, "edit_find", this, SLOT(find()));
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_find", m_searchAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_find", m_searchAction);
 
     return true;
 }
@@ -415,7 +415,7 @@ SKGError SKGSearchPlugin::executeAdviceCorrection(const QString& iAdviceIdentifi
         QString id = iAdviceIdentifier.right(iAdviceIdentifier.length() - 22);
         SKGRuleObject rule(m_currentBankDocument, SKGServices::stringToInt(id));
         rule.load();
-        SKGSearchPluginWidget::open(rule);
+        SKGSearchPluginWidget::open(rule); //FIXME //TODO
         return SKGError();
     }
 
