@@ -47,7 +47,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     ui.kView->getShowWidget()->addItem("update", i18nc("Noun, a modification", "Update"), "view-refresh", "t_action_type='U'", "", "", "");
     ui.kView->getShowWidget()->addItem("alarm", i18nc("Noun, an alarm", "Alarm"), "dialog-warning", "t_action_type='A'", "", "", "");
     ui.kView->getShowWidget()->addSeparator();
-    ui.kView->getShowWidget()->addItem("highlighted", i18nc("Adjective, an highlighted item", "Highlighted"), "rating", "t_bookmarked='Y'", "", "", "");
+    ui.kView->getShowWidget()->addItem("highlighted", i18nc("Adjective, an highlighted item", "Highlighted"), "bookmarks", "t_bookmarked='Y'", "", "", "");
     ui.kView->getShowWidget()->setDefaultState("search;update;alarm;highlighted");
 
     //Add Standard KDE Icons to buttons
@@ -83,9 +83,9 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
     //Fill combo boxes
     QStringList attributeForQuery;
-    attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_ACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
+    attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_ACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
     QStringList attributeForUpdate;
-    attributeForUpdate << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported" << "t_REALCATEGORY" << "t_ACCOUNT" << "t_REALREFUND";
+    attributeForUpdate << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_ACCOUNT" << "t_REALREFUND";
 
     //Adding properties
     QStringList properties;
