@@ -38,14 +38,15 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
 
     ui.setupUi(this);
 
+    //Set show widget
+    ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
+    ui.kView->getShowWidget()->addGroupedItem("opened", i18n("Opened"), "task-ongoing", "t_close='N'");
+    ui.kView->getShowWidget()->addGroupedItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'");
+    ui.kView->getShowWidget()->setDefaultState("opened");
+
     ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay("t_name")));
     ui.kCommentLabel->setText(i18n("%1:", iDocument->getDisplay("t_comment")));
 
-    ui.kView->getShowWidget()->addItem("opened", i18n("Opened"), "", "t_close='N'", "", "", "closed");
-    ui.kView->getShowWidget()->addItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'", "", "", "opened");
-
-    ui.kView->getShowWidget()->setDefaultState("opened");
-
     ui.kAddButton->setIcon(KIcon("list-add"));
     ui.kModifyButton->setIcon(KIcon("dialog-ok-apply"));
 
