@@ -73,7 +73,7 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     actionCollection()->addAction(QLatin1String("edit_split_stock"), m_splitShareAction);
     m_splitShareAction->setShortcut(Qt::ALT + Qt::Key_Slash);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_split_stock", m_splitShareAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_split_stock", m_splitShareAction);
     return true;
 }
 
@@ -84,7 +84,7 @@ int SKGUnitPlugin::getNbDashboardWidgets()
 
 QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    if (iIndex == 0) return i18nc("Noun, the title of a section", "Shares && Indexes");
+    if (iIndex == 0) return i18nc("Noun, the title of a section", "Quotes");
     return "";
 }
 
@@ -125,6 +125,9 @@ void SKGUnitPlugin::refresh()
                             //Create default unit
                             SKGUnitObject unit;
                             err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, locale->currencyCode(), unit);
+
+                            //The file is considered has not modified
+                            m_currentBankDocument->setFileNotModified();
                         }
                     } else if (skgunit_settings::download_on_open()) {
                         //Check frequency
