@@ -66,7 +66,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
             "",
             "currency;share;index;object",//Check when checked
             "highlighted");//Uncheck when checked
-    ui.kUnitTableViewEdition->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "rating", "t_bookmarked='Y'", "", "all;currency;share;index;object", "all");
+    ui.kUnitTableViewEdition->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "bookmarks", "t_bookmarked='Y'", "", "all;currency;share;index;object", "all");
     ui.kUnitTableViewEdition->getShowWidget()->addSeparator();
     ui.kUnitTableViewEdition->getShowWidget()->addItem("currency", i18nc("Noun, a country's currency", "Currency"), "",
             "t_type IN ('1','2','C')",
@@ -455,7 +455,7 @@ void SKGUnitPluginWidget::onModifyUnit()
     SKGError err;
     SKGTRACEINRC(10, "SKGUnitPluginWidget::onModifyUnit", err);
     //Get Selection
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
+    SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
 
     int nb = selection.count();
 
@@ -542,7 +542,7 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
     if (act) mode = (SKGUnitObject::UnitDownloadMode) act->data().toInt();
     else mode = SKGUnitPluginWidget::getDownloadModeFromSettings();
 
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
+    SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
     int nb = selection.count();
     if (nb) {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Download values"), err, nb);
@@ -565,7 +565,7 @@ void SKGUnitPluginWidget::onSimplify()
     SKGError err;
     SKGTRACEINRC(10, "SKGUnitPluginWidget::onSimplify", err);
 
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
+    SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
     int nb = selection.count();
     if (nb) {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Simplify unit values"), err, nb);
