@@ -123,7 +123,7 @@ void SKGObjectModel::buidCache()
         m_fontDisabledScheduleColor = qVariantFromValue(pref.readEntry("fontFutureColor", QColor(Qt::gray)));
     }
 
-    m_iconFavorite = KIcon("rating");
+    m_iconFavorite = KIcon("bookmarks");
 
     if (m_operationTable || m_recurrentoperationTable) {
         m_iconTransfer = KIcon("view-financial-transfer");
@@ -141,7 +141,7 @@ void SKGObjectModel::buidCache()
         m_iconRecurrent = KIcon("chronometer");
         {
             QStringList overlay;
-            overlay.push_back("rating");
+            overlay.push_back("bookmarks");
             m_iconRecurrentMaster = KIcon("chronometer", NULL, overlay);
         }
     }
@@ -296,15 +296,15 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
                 SKGServices::SKGUnitInfo unit;
                 unit.Symbol = "";
                 unit.NbDecimal = 2;
-                if (!att.contains("QUANTITY")) {
+                if (!att.contains("QUANTITY") && !att.contains("f_BALANCE_ENTERED")) {
                     unit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
                     if (m_unitvalueTable && !m_cacheUnit.Symbol.isEmpty()) {
                         unit = m_cacheUnit;
                     }
                 } else {
-                    if (att == "f_QUANTITYOWNED") {
-                        unit.NbDecimal = SKGServices::stringToInt(obj->getAttribute("i_nbdecimal"));
-                    } else {
+                    unit.NbDecimal = SKGServices::stringToInt(obj->getAttribute("i_NBDEC"));
+                    if (unit.NbDecimal == 0) unit.NbDecimal = 2;
+                    if (att != "f_QUANTITYOWNED") {
                         unit.Symbol = obj->getAttribute("t_UNIT");
                     }
                 }
