@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -35,7 +35,7 @@ SKGPropertyEditor::SKGPropertyEditor(QWidget* parent):
     m_listOperations << i18nc("Define an attribute's value using the value of another attribute", "From attribute...");
     m_listOperations << i18nc("Change the case of a string, as in lowercase, uppercase...", "Change case...");
 
-    for(int i = 0 ; i < m_listOperations.count() ; i++) {
+    for (int i = 0 ; i < m_listOperations.count() ; ++i) {
         ui.operationSelect->addItem(m_listOperations.at(i));
     }
 
@@ -62,17 +62,17 @@ void SKGPropertyEditor::setParameters(SKGDocument* iDocument, const QString& iTa
     m_document = iDocument;
     m_table = iTable;
 
-    if(m_document) {
+    if (m_document) {
         //Keep only existing attribute
         SKGServices::SKGAttributesList attributes;
         m_document->getAttributesDescription(m_table, attributes);
         foreach(const SKGServices::SKGAttributeInfo & att, attributes) {
-            if(iEditableAttribute.count() == 0 || iEditableAttribute.contains(att.name)) m_listAtts.push_back(att);
+            if (iEditableAttribute.count() == 0 || iEditableAttribute.contains(att.name)) m_listAtts.push_back(att);
         }
 
 
         int nbCol = m_listAtts.count();
-        for(int i = 0; i < nbCol; ++i) {
+        for (int i = 0; i < nbCol; ++i) {
             ui.attributeSelect->addItem(m_listAtts.at(i).icon, (QString) m_listAtts.at(i).display);
         }
 
@@ -80,12 +80,12 @@ void SKGPropertyEditor::setParameters(SKGDocument* iDocument, const QString& iTa
         SKGServices::SKGAttributesList otherAttributes;
         m_document->getAttributesDescription(m_table, otherAttributes);
         foreach(const SKGServices::SKGAttributeInfo & att, otherAttributes) {
-            if(iOtherAttributes.count() == 0 || iOtherAttributes.contains(att.name)) m_listOtherAtts.push_back(att);
+            if (iOtherAttributes.count() == 0 || iOtherAttributes.contains(att.name)) m_listOtherAtts.push_back(att);
         }
 
 
         int nbOthCol = m_listOtherAtts.count();
-        for(int i = 0; i < nbOthCol; ++i) {
+        for (int i = 0; i < nbOthCol; ++i) {
             ui.otherAttributeSelect->addItem(m_listOtherAtts.at(i).icon, (QString) m_listOtherAtts.at(i).display);
         }
 
@@ -106,7 +106,7 @@ void SKGPropertyEditor::setupWidgets()
 
     ui.valueSelect->setVisible(attributeType == SKGServices::TEXT && operationIndex == 0);
     QStringList attributeValues;
-    if(m_document) m_document->getDistinctValues(m_table, m_listAtts.at(attributeIndex).name, attributeValues);
+    if (m_document) m_document->getDistinctValues(m_table, m_listAtts.at(attributeIndex).name, attributeValues);
     ui.valueSelect->clear();
     ui.valueSelect->addItem("");
 
