@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -41,7 +41,7 @@ SKGAccountObject::SKGAccountObject(const SKGAccountObject& iObject)
 SKGAccountObject::SKGAccountObject(const SKGNamedObject& iObject)
     : SKGNamedObject(iObject.getDocument(), "v_account", iObject.getID())
 {
-    if(iObject.getRealTable() == "account") {
+    if (iObject.getRealTable() == "account") {
         copyFrom(iObject);
     } else {
         *this = SKGNamedObject(iObject.getDocument(), "v_account", iObject.getID());
@@ -50,14 +50,14 @@ SKGAccountObject::SKGAccountObject(const SKGNamedObject& iObject)
 
 SKGAccountObject::SKGAccountObject(const SKGObjectBase& iObject)
 {
-    if(iObject.getRealTable() == "account") {
+    if (iObject.getRealTable() == "account") {
         copyFrom(iObject);
     } else {
         *this = SKGNamedObject(iObject.getDocument(), "v_account", iObject.getID());
     }
 }
 
-const SKGAccountObject& SKGAccountObject::operator= (const SKGObjectBase & iObject)
+const SKGAccountObject& SKGAccountObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -67,23 +67,23 @@ SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObjec
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGAccountObject::setInitialBalance", err);
-    if(getDocument()) {
+    if (getDocument()) {
         //Delete previous initial balance for this account
-        err = getDocument()->executeSqliteOrder("DELETE FROM operation  WHERE d_date='0000-00-00' AND rd_account_id=" + SKGServices::intToString(getID()));
+        err = getDocument()->executeSqliteOrder("DELETE FROM operation  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()));
 
         //Creation of new initial balance
-        if(err.isSucceeded()) {
+        if (!err) {
             SKGOperationObject initialBalanceOp;
             err = addOperation(initialBalanceOp);
-            if(err.isSucceeded()) err = initialBalanceOp.setAttribute("d_date", "0000-00-00");
-            if(err.isSucceeded()) err = initialBalanceOp.setUnit(iUnit);
-            if(err.isSucceeded()) err = initialBalanceOp.setStatus(SKGOperationObject::CHECKED);
-            if(err.isSucceeded()) err = initialBalanceOp.save();
+            if (!err) err = initialBalanceOp.setAttribute("d_date", "0000-00-00");
+            if (!err) err = initialBalanceOp.setUnit(iUnit);
+            if (!err) err = initialBalanceOp.setStatus(SKGOperationObject::CHECKED);
+            if (!err) err = initialBalanceOp.save();
 
             SKGSubOperationObject initialBalanceSubOp;
-            if(err.isSucceeded()) err = initialBalanceOp.addSubOperation(initialBalanceSubOp);
-            if(err.isSucceeded()) err = initialBalanceSubOp.setQuantity(iBalance);
-            if(err.isSucceeded()) err = initialBalanceSubOp.save();
+            if (!err) err = initialBalanceOp.addSubOperation(initialBalanceSubOp);
+            if (!err) err = initialBalanceSubOp.setQuantity(iBalance);
+            if (!err) err = initialBalanceSubOp.save();
         }
     }
     return err;
@@ -100,14 +100,14 @@ SKGError SKGAccountObject::getInitialBalance(double& oBalance, SKGUnitObject& oU
 
     //Get initial balance
     SKGStringListList listTmp;
-    err = getDocument()->executeSelectSqliteOrder("SELECT f_QUANTITY, t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" + SKGServices::intToString(getID()), listTmp);
-    if(err.isSucceeded() && listTmp.count() > 1) {
+    err = getDocument()->executeSelectSqliteOrder("SELECT f_QUANTITY, t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
+    if (!err && listTmp.count() > 1) {
         oBalance = SKGServices::stringToDouble(listTmp.at(1).at(0));
         unitName = listTmp.at(1).at(1);
 
         oUnit = SKGUnitObject(getDocument());
         err = oUnit.setSymbol(unitName);
-        if(err.isSucceeded()) err = oUnit.load();
+        if (!err) err = oUnit.load();
     }
     return err;
 }
@@ -119,7 +119,7 @@ SKGError SKGAccountObject::setBank(const SKGBankObject& iBank)
 
 SKGError SKGAccountObject::getBank(SKGBankObject& oBank) const
 {
-    SKGError err = getDocument()->getObject("v_bank", "id=" + getAttribute("rd_bank_id"), oBank);
+    SKGError err = getDocument()->getObject("v_bank", "id=" % getAttribute("rd_bank_id"), oBank);
     return err;
 }
 
@@ -166,7 +166,7 @@ QString SKGAccountObject::getAgencyAddress() const
 SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation)
 {
     SKGError err;
-    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addOperation")));
+    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addOperation")));
     else {
         oOperation = SKGOperationObject(getDocument());
         err = oOperation.setParentAccount(*this);
@@ -177,16 +177,16 @@ SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation)
 int SKGAccountObject::getNbOperation() const
 {
     int nb = 0;
-    if(getDocument()) getDocument()->getNbObjects("operation", "rd_account_id=" + SKGServices::intToString(getID()), nb);
+    if (getDocument()) getDocument()->getNbObjects("operation", "rd_account_id=" % SKGServices::intToString(getID()), nb);
     return nb;
 }
 
 SKGError SKGAccountObject::getOperations(SKGListSKGObjectBase& oOperations) const
 {
     SKGError err;
-    if(getDocument()) {
+    if (getDocument()) {
         err = getDocument()->getObjects("v_operation",
-                                        "rd_account_id=" + SKGServices::intToString(getID()) ,
+                                        "rd_account_id=" % SKGServices::intToString(getID()) ,
                                         oOperations);
     }
     return err;
@@ -200,26 +200,26 @@ double SKGAccountObject::getCurrentAmount() const
 double SKGAccountObject::getAmount(const QDate& iDate) const
 {
     double output = 0;
-    if(getDocument()) {
+    if (getDocument()) {
         SKGStringListList listTmp;
         SKGError err = getDocument()->executeSelectSqliteOrder("SELECT TOTAL(f_QUANTITY), rc_unit_id FROM v_operation  WHERE "
-                       "d_date<='" + SKGServices::dateToSqlString(QDateTime(iDate)) + "' AND t_template='N' AND rd_account_id=" + SKGServices::intToString(getID()) +
+                       "d_date<='" % SKGServices::dateToSqlString(QDateTime(iDate)) % "' AND t_template='N' AND rd_account_id=" % SKGServices::intToString(getID()) %
                        " GROUP BY rc_unit_id",
                        listTmp);
         int nb = listTmp.count();
-        for(int i = 1; err.isSucceeded() && i < nb ; ++i) {
+        for (int i = 1; !err && i < nb ; ++i) {
             QString quantity = listTmp.at(i).at(0);
             QString unitid = listTmp.at(i).at(1);
 
             double coef = 1;
-            QString val = getDocument()->getCachedValue("unitvalue-" + unitid);
-            if(!val.isEmpty()) {
+            QString val = getDocument()->getCachedValue("unitvalue-" % unitid);
+            if (!val.isEmpty()) {
                 //Yes
                 coef = SKGServices::stringToDouble(val);
             } else {
                 //No
                 SKGUnitObject unit(getDocument(), SKGServices::stringToInt(unitid));
-                coef = unit.getAmount(iDate);
+                if (unit.getType() != SKGUnitObject::PRIMARY) coef = unit.getAmount(iDate);
             }
 
             output += coef * SKGServices::stringToDouble(quantity);
@@ -231,14 +231,14 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
 SKGError SKGAccountObject::setType(SKGAccountObject::AccountType iType)
 {
     SKGError err;
-    if(err.isSucceeded()) err = setAttribute("t_type", (iType == CURRENT ? "C" : (iType == CREDITCARD ? "D" : (iType == ASSETS ? "A" : (iType == INVESTMENT ? "I" : "O")))));
+    if (!err) err = setAttribute("t_type", (iType == CURRENT ? "C" : (iType == CREDITCARD ? "D" : (iType == ASSETS ? "A" : (iType == INVESTMENT ? "I" : (iType == WALLET ? "W" : (iType == LOAN ? "L" : "O")))))));
     return err;
 }
 
 SKGAccountObject::AccountType SKGAccountObject::getType() const
 {
     QString typeString = getAttribute("t_type");
-    return (typeString == "C" ? CURRENT : (typeString == "D" ? CREDITCARD : (typeString == "A" ? ASSETS : (typeString == "I" ? INVESTMENT : OTHER))));
+    return (typeString == "C" ? CURRENT : (typeString == "D" ? CREDITCARD : (typeString == "A" ? ASSETS : (typeString == "I" ? INVESTMENT : (typeString == "W" ? (typeString == "L" ? LOAN : OTHER) : OTHER)))));
 }
 
 SKGError SKGAccountObject::setClosed(bool iClosed)
@@ -266,21 +266,21 @@ SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
 {
     //Get initial amount
     SKGStringListList listTmp;
-    SKGError err = getDocument()->executeSelectSqliteOrder("SELECT t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" + SKGServices::intToString(getID()), listTmp);
-    if(err.isSucceeded()) {
+    SKGError err = getDocument()->executeSelectSqliteOrder("SELECT t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
+    if (!err) {
         //Is initial amount existing ?
-        if(listTmp.count() > 1) {
+        if (listTmp.count() > 1) {
             //Yes ==> then the amount is the amount of the initial value
             oUnit = SKGUnitObject(getDocument());
             err = oUnit.setSymbol(listTmp.at(1).at(0));
-            if(err.isSucceeded()) err = oUnit.load();
+            if (!err) err = oUnit.load();
         } else {
             //No ==> we get the preferred unit
             SKGObjectBase::SKGListSKGObjectBase units;
             err = getDocument()->getObjects("v_unit",
-                                            "t_type IN ('1', '2', 'C') AND EXISTS(SELECT 1 FROM operation WHERE rc_unit_id=v_unit.id AND rd_account_id=" + SKGServices::intToString(getID()) + ") ORDER BY t_type", units);
+                                            "t_type IN ('1', '2', 'C') AND EXISTS(SELECT 1 FROM operation WHERE rc_unit_id=v_unit.id AND rd_account_id=" % SKGServices::intToString(getID()) % ") ORDER BY t_type", units);
             int nb = units.count();
-            if(nb) oUnit = units.at(0);
+            if (nb) oUnit = units.at(0);
         }
     }
     return err;
@@ -289,7 +289,7 @@ SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
 SKGError SKGAccountObject::addInterest(SKGInterestObject& oInterest)
 {
     SKGError err;
-    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addInterest")));
+    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addInterest")));
     else {
         oInterest = SKGInterestObject(static_cast<SKGDocumentBank*>(getDocument()));
         err = oInterest.setAccount(*this);
@@ -300,7 +300,7 @@ SKGError SKGAccountObject::addInterest(SKGInterestObject& oInterest)
 SKGError SKGAccountObject::getInterests(SKGListSKGObjectBase& oInterestList) const
 {
     SKGError err = getDocument()->getObjects("v_interest",
-                   "rd_account_id=" + SKGServices::intToString(getID()),
+                   "rd_account_id=" % SKGServices::intToString(getID()),
                    oInterestList);
     return err;
 }
@@ -310,18 +310,18 @@ SKGError SKGAccountObject::getInterest(const QDate& iDate, SKGInterestObject& oI
     QString ids = SKGServices::intToString(getID());
     QString dates = SKGServices::dateToSqlString(QDateTime(iDate));
     SKGError err = SKGObjectBase::getDocument()->getObject("v_interest",
-                   "rd_account_id=" + ids + " AND d_date<='" + dates +
-                   "' AND  ABS(strftime('%s','" + dates +
-                   "')-strftime('%s',d_date))=(SELECT MIN(ABS(strftime('%s','" + dates +
-                   "')-strftime('%s',u2.d_date))) FROM interest u2 WHERE u2.rd_account_id=" + ids +
-                   " AND u2.d_date<='" + dates + "')",
+                   "rd_account_id=" % ids % " AND d_date<='" % dates %
+                   "' AND  ABS(strftime('%s','" % dates %
+                   "')-strftime('%s',d_date))=(SELECT MIN(ABS(strftime('%s','" % dates %
+                   "')-strftime('%s',u2.d_date))) FROM interest u2 WHERE u2.rd_account_id=" % ids %
+                   " AND u2.d_date<='" % dates % "')",
                    oInterest);
 
     //If not found then get first
-    if(err.isFailed()) err = SKGObjectBase::getDocument()->getObject("v_interest",
-                                 "rd_account_id=" + SKGServices::intToString(getID()) + " AND d_date=(SELECT MIN(d_date) FROM interest WHERE rd_account_id=" +
-                                 SKGServices::intToString(getID()) + ')',
-                                 oInterest);
+    if (err) err = SKGObjectBase::getDocument()->getObject("v_interest",
+                       "rd_account_id=" % SKGServices::intToString(getID()) % " AND d_date=(SELECT MIN(d_date) FROM interest WHERE rd_account_id=" %
+                       SKGServices::intToString(getID()) % ')',
+                       oInterest);
     return err;
 }
 
@@ -332,7 +332,7 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
 
     //Initial date
     int y = iYear;
-    if(y == 0) y = QDate::currentDate().year();
+    if (y == 0) y = QDate::currentDate().year();
     QDate initialDate = QDate(y, 1, 1);
     QDate lastDate = QDate(y, 12, 31);
 
@@ -341,11 +341,11 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
 
     //Add operations
     SKGObjectBase::SKGListSKGObjectBase items;
-    err = getDocument()->getObjects("v_operation", "rd_account_id=" + SKGServices::intToString(getID()) +
-                                    " AND d_date>='" + SKGServices::dateToSqlString(QDateTime(initialDate)) + "' "
-                                    " AND d_date<='" + SKGServices::dateToSqlString(QDateTime(lastDate)) + "' ORDER BY d_date", items);
+    err = getDocument()->getObjects("v_operation", "rd_account_id=" % SKGServices::intToString(getID()) %
+                                    " AND d_date>='" % SKGServices::dateToSqlString(QDateTime(initialDate)) % "' "
+                                    " AND d_date<='" % SKGServices::dateToSqlString(QDateTime(lastDate)) % "' ORDER BY d_date", items);
     int nb = items.count();
-    for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+    for (int i = 0; !err && i < nb; ++i) {
         SKGOperationObject ob = items.at(i);
 
         SKGInterestItem itemI;
@@ -363,14 +363,14 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
     }
 
     //Add interest
-    if(err.isSucceeded()) {
-        err = getDocument()->getObjects("v_interest", "rd_account_id=" + SKGServices::intToString(getID()) +
-                                        " AND d_date>='" + SKGServices::dateToSqlString(QDateTime(initialDate)) + "' "
-                                        " AND d_date<='" + SKGServices::dateToSqlString(QDateTime(lastDate)) + "' ORDER BY d_date", items);
+    if (!err) {
+        err = getDocument()->getObjects("v_interest", "rd_account_id=" % SKGServices::intToString(getID()) %
+                                        " AND d_date>='" % SKGServices::dateToSqlString(QDateTime(initialDate)) % "' "
+                                        " AND d_date<='" % SKGServices::dateToSqlString(QDateTime(lastDate)) % "' ORDER BY d_date", items);
 
         int pos = 0;
         int nb = items.count();
-        for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+        for (int i = 0; !err && i < nb; ++i) {
             SKGInterestObject ob = items.at(i);
 
             SKGInterestItem itemI;
@@ -385,8 +385,8 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
             itemI.amount = 0;
 
             int nb2 = oInterestList.count();
-            for(int j = pos; err.isSucceeded() && j < nb2; ++j) {
-                if(itemI.date <= oInterestList.at(j).date) {
+            for (int j = pos; !err && j < nb2; ++j) {
+                if (itemI.date <= oInterestList.at(j).date) {
                     break;
                 } else {
                     ++pos;
@@ -399,10 +399,10 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
     }
 
     //Get first interest
-    if(err.isSucceeded()) {
+    if (!err) {
         SKGInterestObject firstInterest;
-        if(getInterest(initialDate, firstInterest).isSucceeded()) {
-            if(firstInterest.getDate() < initialDate) {
+        if (getInterest(initialDate, firstInterest).isSucceeded()) {
+            if (firstInterest.getDate() < initialDate) {
                 SKGInterestItem itemI;
                 itemI.object = firstInterest;
                 itemI.date = initialDate;
@@ -421,13 +421,13 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
     }
 
     //Launch computation
-    if(err.isSucceeded()) {
-        if(computationNeeded) {
+    if (!err) {
+        if (computationNeeded) {
 
             err = computeInterestItems(oInterestList, oInterests, y);
         } else {
             //Drop temporary table
-            if(err.isSucceeded()) {
+            if (!err) {
                 err = getDocument()->executeSqliteOrder("DROP TABLE IF EXISTS interest_result");
             }
         }
@@ -444,7 +444,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
 
     //Initial date
     int y = iYear;
-    if(y == 0) y = QDate::currentDate().year();
+    if (y == 0) y = QDate::currentDate().year();
     QDate initialDate = QDate(y, 1, 1);
 
     //Default interest item
@@ -457,10 +457,10 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
     currentInterest.accruedInterest = 0;
 
     int nb = ioInterestList.count();
-    for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+    for (int i = 0; !err && i < nb; ++i) {
         SKGInterestItem tmp = ioInterestList.at(i);
         SKGObjectBase object = tmp.object;
-        if(object.getRealTable() == "operation") {
+        if (object.getRealTable() == "operation") {
             //Get operations
             SKGOperationObject op = object;
 
@@ -470,7 +470,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
             //Get value date computation mode
             SKGInterestObject::ValueDateMode valueMode = SKGInterestObject::FIFTEEN;
             SKGInterestObject::InterestMode baseMode = SKGInterestObject::FIFTEEN24;
-            if(currentInterest.object.getRealTable() == "interest") {
+            if (currentInterest.object.getRealTable() == "interest") {
                 SKGInterestObject interestObj = currentInterest.object;
                 valueMode = (tmp.amount >= 0 ? interestObj.getIncomeValueDateMode() : interestObj.getExpenditueValueDateMode());
                 baseMode = interestObj.getInterestComputationMode();
@@ -479,13 +479,13 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
             }
 
             //Compute value date
-            if(object.getRealTable() == "operation") {
-                if(valueMode == SKGInterestObject::FIFTEEN) {
-                    if(tmp.amount >= 0) {
-                        if(tmp.date.day() <= 15) tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
+            if (object.getRealTable() == "operation") {
+                if (valueMode == SKGInterestObject::FIFTEEN) {
+                    if (tmp.amount >= 0) {
+                        if (tmp.date.day() <= 15) tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
                         else tmp.valueDate = tmp.date.addMonths(1).addDays(1 - tmp.date.day());
                     } else {
-                        if(tmp.date.day() <= 15) tmp.valueDate = tmp.date.addDays(1 - tmp.date.day());
+                        if (tmp.date.day() <= 15) tmp.valueDate = tmp.date.addDays(1 - tmp.date.day());
                         else tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
                     }
                 } else {
@@ -494,11 +494,11 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
             }
 
             //Compute coef
-            if(baseMode == SKGInterestObject::DAYS365) {
+            if (baseMode == SKGInterestObject::DAYS365) {
                 QDate last(tmp.date.year(), 12, 31);
                 tmp.coef = tmp.valueDate.daysTo(last) + 1;
                 tmp.coef /= 365;
-            } else if(baseMode == SKGInterestObject::DAYS360) {
+            } else if (baseMode == SKGInterestObject::DAYS360) {
                 QDate last(tmp.date.year(), 12, 31);
                 tmp.coef = 360 * (last.year() - tmp.valueDate.year()) + 30 * (last.month() - tmp.valueDate.month()) + (last.day() - tmp.valueDate.day()); //TODO must be confirmed
                 tmp.coef /= 360;
@@ -506,18 +506,18 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
                 tmp.coef = 2 * (12 - tmp.valueDate.month()) + (tmp.valueDate.day() <= 15 ? 2 : 1);
                 tmp.coef /= 24;
             }
-            if(tmp.valueDate.year() != iYear) tmp.coef = 0;
+            if (tmp.valueDate.year() != iYear) tmp.coef = 0;
 
             //Compute annual interest
             tmp.annualInterest = tmp.amount * tmp.coef * tmp.rate / 100;
 
-        } else if(object.getRealTable() == "interest") {
+        } else if (object.getRealTable() == "interest") {
             //Compute coef
-            if(tmp.base == 365) {
+            if (tmp.base == 365) {
                 QDate last(tmp.date.year(), 12, 31);
                 tmp.coef = tmp.valueDate.daysTo(last) + 1;
                 tmp.coef /= 365;
-            } else if(tmp.base == 360) {
+            } else if (tmp.base == 360) {
                 QDate last(tmp.date.year(), 12, 31);
                 tmp.coef = 360 * (last.year() - tmp.valueDate.year()) + 30 * (last.month() - tmp.valueDate.month()) + (last.day() - tmp.valueDate.day()); //TODO must be confirmed
                 tmp.coef /= 360;
@@ -525,7 +525,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
                 tmp.coef = 2 * (12 - tmp.valueDate.month()) + (tmp.valueDate.day() <= 15 ? 2 : 1);
                 tmp.coef /= 24;
             }
-            if(tmp.valueDate.year() != iYear) tmp.coef = 0;
+            if (tmp.valueDate.year() != iYear) tmp.coef = 0;
 
             //Compute annual interest
             tmp.amount = getAmount(tmp.valueDate);
@@ -545,7 +545,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
     }
 
     //Create temporary table
-    if(err.isSucceeded()) {
+    if (!err) {
         QStringList sqlOrders;
         sqlOrders << "DROP TABLE IF EXISTS interest_result"
                   << "CREATE TEMP TABLE interest_result("
@@ -563,19 +563,19 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
 
         //Fill table
         int nb = ioInterestList.count();
-        for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+        for (int i = 0; !err && i < nb; ++i) {
             SKGInterestItem interest = ioInterestList.at(i);
             SKGObjectBase object = interest.object;
             QString sqlinsert =
                 "INSERT INTO interest_result (d_date,d_valuedate,t_comment,f_currentamount,f_coef,f_rate,f_annual_interest,f_accrued_interest) "
-                " VALUES ('" + SKGServices::dateToSqlString(QDateTime(interest.date)) +
-                "','" + SKGServices::dateToSqlString(QDateTime(interest.valueDate)) +
-                "','" + SKGServices::stringToSqlString(object.getRealTable() == "operation" ? i18nc("Noun", "Relative to operation '%1'", SKGOperationObject(object).getDisplayName()) : i18nc("Noun", "Rate change")) +
-                "'," + SKGServices::doubleToString(interest.amount) +
-                ',' + SKGServices::doubleToString(interest.coef) +
-                ',' + SKGServices::doubleToString(interest.rate) +
-                ',' + SKGServices::doubleToString(interest.annualInterest) +
-                ',' + SKGServices::doubleToString(interest.accruedInterest) +
+                " VALUES ('" % SKGServices::dateToSqlString(QDateTime(interest.date)) %
+                "','" % SKGServices::dateToSqlString(QDateTime(interest.valueDate)) %
+                "','" % SKGServices::stringToSqlString(object.getRealTable() == "operation" ? i18nc("Noun", "Relative to operation '%1'", SKGOperationObject(object).getDisplayName()) : i18nc("Noun", "Rate change")) %
+                "'," % SKGServices::doubleToString(interest.amount) %
+                ',' % SKGServices::doubleToString(interest.coef) %
+                ',' % SKGServices::doubleToString(interest.rate) %
+                ',' % SKGServices::doubleToString(interest.annualInterest) %
+                ',' % SKGServices::doubleToString(interest.accruedInterest) %
                 ")";
 
             err = getDocument()->executeSqliteOrder(sqlinsert);
@@ -591,12 +591,12 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
     SKGTRACEINRC(10, "SKGAccountObject::autoReconcile", err);
     //
     SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
-    if(doc) {
+    if (doc) {
         //Get unit
         SKGServices::SKGUnitInfo unit1 = doc->getPrimaryUnit();
         SKGUnitObject unitAccount;
-        if(getUnit(unitAccount).isSucceeded()) {
-            if(!unitAccount.getSymbol().isEmpty()) {
+        if (getUnit(unitAccount).isSucceeded()) {
+            if (!unitAccount.getSymbol().isEmpty()) {
                 unit1.Symbol = unitAccount.getSymbol();
                 unit1.Value = SKGServices::stringToDouble(unitAccount.getAttribute("f_CURRENTAMOUNT"));
             }
@@ -606,20 +606,20 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         double balance = 0;
         SKGStringListList listTmp2;
         err = getDocument()->executeSelectSqliteOrder(
-                  "SELECT TOTAL(f_CHECKED) from v_account_display WHERE id=" + SKGServices::intToString(getID()),
+                  "SELECT TOTAL(f_CHECKED) from v_account_display WHERE id=" % SKGServices::intToString(getID()),
                   listTmp2);
-        if(listTmp2.count() == 2) balance = SKGServices::stringToDouble(listTmp2.at(1).at(0)) / unit1.Value;
+        if (listTmp2.count() == 2) balance = SKGServices::stringToDouble(listTmp2.at(1).at(0)) / unit1.Value;
 
 
         //Get all imported operation
         double diff = balance - iBalance;
         SKGObjectBase::SKGListSKGObjectBase operations;
-        if(err.isSucceeded()) err = getDocument()->getObjects("v_operation", "rd_account_id=" + SKGServices::intToString(getID()) + " AND t_status='N' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations);
+        if (!err) err = getDocument()->getObjects("v_operation", "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='N' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations);
 
 
         //Comparison
         QString zero = doc->formatMoney(0, unit1);
-        QString negativezero = doc->formatMoney(-0.00001, unit1);
+        QString negativezero = doc->formatMoney(-EPSILON, unit1);
 
         //Try to find the soluce
         int nb = operations.count();
@@ -627,26 +627,26 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         QString sdiff = doc->formatMoney(diff, unit1);
         int limit = -1;
         bool moreThanOneSoluceFound = false;
-        for(int i = 0; !moreThanOneSoluceFound && err.isSucceeded() && i < nb; ++i) {
+        for (int i = 0; !moreThanOneSoluceFound && !err && i < nb; ++i) {
             SKGOperationObject op = operations.at(i);
             double amount = op.getCurrentAmount();
             diff += amount;
             sdiff = doc->formatMoney(diff, unit1);
             SKGTRACEL(5) << (i + 1) << "/" << nb << ": Amount=" << amount << " / New diff=" << sdiff << endl;
-            if(sdiff == zero || sdiff == negativezero) {
-                if(limit != -1) {
-                    err = getDocument()->sendMessage(i18nc("An information message",  "More than one solution is possible for this auto reconcilation."));
+            if (sdiff == zero || sdiff == negativezero) {
+                if (limit != -1) {
+                    err = getDocument()->sendMessage(i18nc("An information message",  "More than one solution is possible for this auto reconciliation."));
                     moreThanOneSoluceFound = true;
                 } else limit = i;
             }
         }
 
         //Check all
-        if(limit != -1) {
-            for(int i = 0; err.isSucceeded() && i <= limit; ++i) {
+        if (limit != -1) {
+            for (int i = 0; !err && i <= limit; ++i) {
                 SKGOperationObject op = operations.at(i);
                 err = op.setStatus(SKGOperationObject::POINTED);
-                if(err.isSucceeded()) err = op.save(true, false);
+                if (!err) err = op.save(true, false);
             }
         } else {
             err = SKGError(ERR_FAIL, i18nc("Error message",  "Can not find the imported operations for obtaining the expected final balance"));
@@ -668,27 +668,27 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
 
     double balance2;
     SKGUnitObject unit2;
-    if(err.isSucceeded()) err = const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2);
+    if (!err) err = const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2);
 
     //Transfert operations
     SKGObjectBase::SKGListSKGObjectBase ops;
-    if(err.isSucceeded()) err = iAccount.getOperations(ops);
+    if (!err) err = iAccount.getOperations(ops);
     int nb = ops.count();
-    for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+    for (int i = 0; !err && i < nb; ++i) {
         SKGOperationObject op = ops.at(i);
         err = op.setParentAccount(*this);
-        if(err.isSucceeded()) err = op.save(true, false);
+        if (!err) err = op.save(true, false);
     }
 
     //Set initial balance
     SKGUnitObject unit = unit1;
-    if(!unit1.exist()) unit = unit2;
-    if(unit.exist()) {
+    if (!unit1.exist()) unit = unit2;
+    if (unit.exist()) {
         double balance = balance1 + SKGUnitObject::convert(balance2, unit2, unit);
-        if(err.isSucceeded()) err = setInitialBalance(balance, unit);
+        if (!err) err = setInitialBalance(balance, unit);
     }
     //Remove account
-    if(err.isSucceeded()) err = iAccount.remove();
+    if (!err) err = iAccount.remove();
     return err;
 }
 
