@@ -200,7 +200,7 @@ SKGError SKGCategoryObject::getParentCategory(SKGCategoryObject& oCategory) cons
 {
     SKGError err;
     QString parent_id = getAttribute("rd_category_id");
-    if (!parent_id.isEmpty()) err = getDocument()->getObject("v_category", "id=" % parent_id , oCategory);
+    if (!parent_id.isEmpty() && parent_id != "0") err = getDocument()->getObject("v_category", "id=" % parent_id , oCategory);
     return err;
 }
 
