@@ -94,23 +94,6 @@ public Q_SLOTS:
      */
     virtual SKGError addOrModifyUnitValue(const QString& iUnitName, const QDate& iDate, double iValue, SKGUnitValueObject* oValue = NULL);
 
-    /**
-     * Get formated money
-     * @param iValue value
-     * @param iUnit unit
-     * @param iHtml colored output
-     * @return formated value in red or black
-     */
-    virtual QString formatMoney(double iValue, SKGServices::SKGUnitInfo iUnit, bool iHtml = true) const;
-
-    /**
-        * Get formated percentage
-        * @param iValue value
-        * @param iInvertColors to set positive value in red and negative values in green
-        * @return formated value in red or black
-        */
-    virtual QString formatPercentage(double iValue, bool iInvertColors = false) const;
-
     /**
      * Get Primary unit. WARNING: This value can be not uptodated in a transaction.
      * @return Primary unit.
@@ -212,6 +195,13 @@ public Q_SLOTS:
      */
     virtual void setComputeBalances(bool iEnabled);
 
+    /**
+     * Get the report
+     * Do not forget to delete the pointer
+     * @return the report
+     */
+    virtual SKGReport* getReport();
+
 protected:
     /**
      * Migrate the current SKGDocument to the latest version of the data model.
