@@ -27,16 +27,17 @@
 #include "skgruleobject.h"
 #include "skgpayeeobject.h"
 #include "skgrecurrentoperationobject.h"
+#include "skgimportplugin.h"
 
 #include <klocale.h>
 #include <ksavefile.h>
+#include <kservicetypetrader.h>
+#include <kio/netaccess.h>
 
 #include <QRegExp>
 #include <QFileInfo>
 #include <QTextCodec>
 #include <QCryptographicHash>
-#include <kservicetypetrader.h>
-#include "skgimportplugin.h"
 
 SKGImportExportManager::SKGImportExportManager(SKGDocumentBank* iDocument,
         const QString& iFileName)
@@ -46,6 +47,8 @@ SKGImportExportManager::SKGImportExportManager(SKGDocumentBank* iDocument,
 {
     setAutomaticValidation(true);
     setAutomaticApplyRules(false);
+
+    KIO::NetAccess::download(KUrl(iFileName), m_localFileName, NULL);
 }
 
 SKGImportExportManager::~SKGImportExportManager()
@@ -57,6 +60,8 @@ SKGImportExportManager::~SKGImportExportManager()
     m_defaultUnit = NULL;
     m_importPlugin = NULL;
     m_exportPlugin = NULL;
+
+    KIO::NetAccess::removeTempFile(m_fileName);
 }
 
 SKGError SKGImportExportManager::setDefaultAccount(SKGAccountObject* iAccount)
@@ -398,6 +403,8 @@ SKGError SKGImportExportManager::importFile()
             if (pluginInterface) {
                 //Import
                 fileTreated = true;
+                SKGTRACEL(2) << "Input filename=" << m_fileName << endl;
+                SKGTRACEL(2) << "Input local filename=" << m_localFileName << endl;
                 err = pluginInterface->importFile();
             }
 
@@ -428,7 +435,11 @@ SKGError SKGImportExportManager::exportFile()
             if (pluginInterface) {
                 //Import
                 fileTreated = true;
+                SKGTRACEL(2) << "Input filename=" << m_fileName << endl;
+                SKGTRACEL(2) << "Input local filename=" << m_localFileName << endl;
                 err = pluginInterface->exportFile();
+                if (!err && !KIO::NetAccess::upload(m_localFileName, KUrl(m_fileName), NULL))
+                    err = SKGError(ERR_WRITEACCESS, KIO::NetAccess::lastErrorString());
             }
 
             if (!err && !fileTreated) {
@@ -544,20 +555,22 @@ SKGError SKGImportExportManager::anonymize()
             err = SKGError(ERR_ABORT, i18nc("An information message",  "The document must be saved to be anonymized."));
         } else {
             {
-                SKGBEGINTRANSACTION(*m_document, "##INTERNAL##" % i18nc("Progression step", "Anonymize"), err);
-                if (!err) {
-                    QStringList sqlOrders;
-                    sqlOrders << "UPDATE bank SET t_bank_number='', t_name='bank_'||id"
-                              << "UPDATE account SET t_number='', t_agency_number='', t_agency_address='', t_comment='', t_name='account_'||id"
-                              << "UPDATE category SET t_name='category_'||id"
-                              << "UPDATE payee SET t_address='', t_name='payee_'||id"
-                              << "UPDATE refund SET t_comment='', t_name='tracker_'||id"
-                              << "UPDATE operation SET t_comment=''"
-                              << "UPDATE suboperation SET t_comment='', f_value=f_value%1234.56"
-                              << "DELETE FROM parameters WHERE t_name='SKG_PASSWORD'"
-                              << "DELETE FROM parameters WHERE t_name NOT LIKE 'SKG_%'"
-                              ;
-                    err = m_document->executeSqliteOrders(sqlOrders);
+                QStringList sqlOrders;
+                sqlOrders << "UPDATE bank SET t_bank_number='', t_name='bank_'||id"
+                          << "UPDATE account SET t_number='', t_agency_number='', t_agency_address='', t_comment='', t_name='account_'||id"
+                          << "UPDATE category SET t_name='category_'||id"
+                          << "UPDATE payee SET t_address='', t_name='payee_'||id"
+                          << "UPDATE refund SET t_comment='', t_name='tracker_'||id"
+                          << "UPDATE operation SET t_comment=''"
+                          << "UPDATE suboperation SET t_comment='', f_value=f_value%1234.56"
+                          << "DELETE FROM parameters WHERE t_name NOT LIKE 'SKG_%' OR t_name='SKG_PASSWORD'"
+                          << "DELETE FROM doctransactionitem"; //For better performances
+
+                int nb = sqlOrders.count();
+                SKGBEGINPROGRESSTRANSACTION(*m_document, "##INTERNAL##" % i18nc("Progression step", "Anonymize"), err, nb);
+                for (int i = 0; !err && i < nb; ++i) {
+                    err = m_document->executeSqliteOrder(sqlOrders.at(i));
+                    if (!err) err = m_document->stepForward(i + 1);
                 }
             }
 
