@@ -173,13 +173,23 @@ public:
     virtual inline SKGDocumentBank* getDocument() {
         return m_document;
     }
+
     /**
-     * Get file name
+     * Get the file name
      * @return the file name.
      */
     virtual inline QString getFileName() {
         return m_fileName;
     }
+
+    /**
+     * Get the local file name
+     * @return the local file name.
+     */
+    virtual inline QString getLocalFileName() {
+        return m_localFileName;
+    }
+
     /**
      * Return the default account for import
      * @param oAccount the default account for import.
@@ -215,6 +225,7 @@ private:
 
     SKGDocumentBank* m_document;
     QString m_fileName;
+    QString m_localFileName;
     SKGAccountObject* m_defaultAccount;
     SKGUnitObject* m_defaultUnit;
     QString m_codec;
