@@ -219,7 +219,8 @@ QDate SKGOperationObject::getDate() const
 
 SKGError SKGOperationObject::getUnit(SKGUnitObject& oUnit) const
 {
-    SKGError err = getDocument()->getObject("v_unit", "id=" % getAttribute("rc_unit_id"), oUnit);
+    SKGError err = (getDocument() == NULL ? SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing")) : getDocument()->getObject("v_unit", "id=" % getAttribute("rc_unit_id"), oUnit));
+    //SKGError err = getDocument()->getObject("v_unit", "id=" % getAttribute("rc_unit_id"), oUnit);
     return err;
 }
 
