@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -89,7 +89,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError duplicate(SKGOperationObject& oOperation, const QDate& iDate = QDate::currentDate(), bool iTemplateMode = false);
+    virtual SKGError duplicate(SKGOperationObject& oOperation, const QDate& iDate = QDate::currentDate(), bool iTemplateMode = false) const;
 
     /**
      * Get the parent account
@@ -352,7 +352,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError addRecurrentOperation(SKGRecurrentOperationObject& oRecurrentOperation);
+    virtual SKGError addRecurrentOperation(SKGRecurrentOperationObject& oRecurrentOperation) const;
 
     /**
      * Get the recurrent operations based on this one
@@ -368,7 +368,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError mergeAtttibute(const SKGOperationObject& iDeletedOne);
+    virtual SKGError mergeAttribute(const SKGOperationObject& iDeletedOne);
 
     /**
      * Merge current operation with another one
