@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -42,14 +42,14 @@ SKGPayeeObject::SKGPayeeObject(const SKGPayeeObject& iObject)
 SKGPayeeObject::SKGPayeeObject(const SKGObjectBase& iObject)
 
 {
-    if(iObject.getRealTable() == "payee") {
+    if (iObject.getRealTable() == "payee") {
         copyFrom(iObject);
     } else {
         *this = SKGNamedObject(iObject.getDocument(), "v_payee", iObject.getID());
     }
 }
 
-const SKGPayeeObject& SKGPayeeObject::operator= (const SKGObjectBase & iObject)
+const SKGPayeeObject& SKGPayeeObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -64,17 +64,17 @@ SKGError SKGPayeeObject::createPayee(SKGDocumentBank* iDocument,
     SKGTRACEINRC(10, "SKGPayeeObject::createPayee", err);
 
     //Check if refund is already existing
-    if(iName.isEmpty()) {
+    if (iName.isEmpty()) {
         oPayee = SKGPayeeObject(NULL, 0);
-    } else if(iDocument) {
-        iDocument->getObject("v_payee", "t_name='" + SKGServices::stringToSqlString(iName) + '\'', oPayee);
-        if(oPayee.getID() == 0) {
+    } else if (iDocument) {
+        iDocument->getObject("v_payee", "t_name='" % SKGServices::stringToSqlString(iName) % '\'', oPayee);
+        if (oPayee.getID() == 0) {
             //No, we have to create it
             oPayee = SKGPayeeObject(iDocument);
             err = oPayee.setName(iName);
-            if(err.isSucceeded()) err = oPayee.save();
+            if (!err) err = oPayee.save();
 
-            if(err.isSucceeded() && iSendPopupMessageOnCreation && iDocument) {
+            if (!err && iSendPopupMessageOnCreation && iDocument) {
                 err = iDocument->sendMessage(i18nc("Information message", "Payee '%1' has been created" , iName), true);
             }
         }
@@ -86,7 +86,7 @@ SKGError SKGPayeeObject::createPayee(SKGDocumentBank* iDocument,
 SKGError SKGPayeeObject::getOperations(SKGListSKGObjectBase& oOperations) const
 {
     SKGError err = getDocument()->getObjects("v_operation",
-                   "r_payee_id=" + SKGServices::intToString(getID()) ,
+                   "r_payee_id=" % SKGServices::intToString(getID()) ,
                    oOperations);
     return err;
 }
@@ -106,20 +106,31 @@ double SKGPayeeObject::getCurrentAmount() const
     return SKGServices::stringToDouble(getAttribute("f_CURRENTAMOUNT"));
 }
 
+SKGError SKGPayeeObject::bookmark(bool iBookmark)
+{
+    return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
+
+}
+
+bool SKGPayeeObject::isBookmarked() const
+{
+    return (getAttribute("t_bookmarked") == "Y" ? true : false);
+}
+
 SKGError SKGPayeeObject::merge(const SKGPayeeObject& iPayee)
 {
     SKGError err;
 
     SKGObjectBase::SKGListSKGObjectBase ops;
-    if(err.isSucceeded()) err = iPayee.getOperations(ops);
+    if (!err) err = iPayee.getOperations(ops);
     int nb = ops.count();
-    for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+    for (int i = 0; !err && i < nb; ++i) {
         SKGOperationObject op = ops.at(i);
         err = op.setPayee(*this);
-        if(err.isSucceeded()) err = op.save(true, false);
+        if (!err) err = op.save(true, false);
     }
 
-    if(err.isSucceeded()) err = iPayee.remove();
+    if (!err) err = iPayee.remove();
     return err;
 }
 
