@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -44,8 +44,9 @@ public:
      * This enumerate defines the period unit
      */
     enum PeriodUnit {DAY = 0,   /**< day */
-                     MONTH = 1, /**< month */
-                     YEAR = 2   /**< year */
+                     WEEK = 1, /**< week */
+                     MONTH = 2, /**< month */
+                     YEAR = 3   /**< year */
                     };
 
     /**
@@ -71,7 +72,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGRecurrentOperationObject& operator= (const SKGObjectBase &iObject);
+    virtual const SKGRecurrentOperationObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
@@ -259,11 +260,12 @@ public:
      * Warn and/or create operations for all recurrent operations of the document
      * @param iDocument the document containing the object
      * @param oNbInserted number of operations inserted
+     * @param iForce to force the insertion even if autowrite is not enable*
      * @param iDate date limite for insertion
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError process(SKGDocumentBank* iDocument, int& oNbInserted, const QDate& iDate = QDate::currentDate());
+    static SKGError process(SKGDocumentBank* iDocument, int& oNbInserted, bool iForce = false, const QDate& iDate = QDate::currentDate());
 };
 /**
  * Declare the class
