@@ -547,6 +547,9 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                         }
                                     }
                                     output.push_back("UPDATE suboperation set r_category_id=(SELECT id FROM category WHERE " % elementDescription % ") WHERE i_tmp=1");
+                                } else if (attribute == "t_REALCOMMENT") {
+                                    elementDescription.replace(attribute, "t_comment");
+                                    output.push_back("UPDATE suboperation set " % elementDescription % " WHERE i_tmp=1 AND NOT(" % elementDescription % ')');
                                 } else if (attribute == "t_ACCOUNT") {
                                     elementDescription.replace(attribute, "t_name");
                                     output.push_back("INSERT OR IGNORE INTO account (t_name, rd_bank_id) VALUES ('" % SKGServices::stringToSqlString(element.attribute("value")) % "', (SELECT MIN(id) FROM bank))");
