@@ -99,6 +99,12 @@ public:
      */
     virtual ~SKGRuleObject();
 
+    /**
+     * Return the name of the object for the display
+     * @return name of the object
+     */
+    virtual QString getDisplayName() const;
+
     /**
      * Set the XML for the search definition
      * @param iXml the XML search definition
