@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -43,14 +43,14 @@ SKGSubOperationObject::SKGSubOperationObject(const SKGSubOperationObject& iObjec
 
 SKGSubOperationObject::SKGSubOperationObject(const SKGObjectBase& iObject)
 {
-    if(iObject.getRealTable() == "suboperation") {
+    if (iObject.getRealTable() == "suboperation") {
         copyFrom(iObject);
     } else {
         *this = SKGObjectBase(iObject.getDocument(), "v_suboperation", iObject.getID());
     }
 }
 
-const SKGSubOperationObject& SKGSubOperationObject::operator= (const SKGObjectBase & iObject)
+const SKGSubOperationObject& SKGSubOperationObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -66,9 +66,19 @@ QString SKGSubOperationObject::getComment() const
     return getAttribute("t_comment");
 }
 
+QString SKGSubOperationObject::getFormula() const
+{
+    return getAttribute("t_formula");
+}
+
+SKGError SKGSubOperationObject::setFormula(const QString& iFormula)
+{
+    return setAttribute("t_formula", iFormula);
+}
+
 SKGError SKGSubOperationObject::getParentOperation(SKGOperationObject& oOperation) const
 {
-    SKGError err = getDocument()->getObject("v_operation", "id=" + getAttribute("rd_operation_id"), oOperation);
+    SKGError err = getDocument()->getObject("v_operation", "id=" % getAttribute("rd_operation_id"), oOperation);
     return err;
 }
 
@@ -80,7 +90,7 @@ SKGError SKGSubOperationObject::setParentOperation(const SKGOperationObject& iOp
 
 SKGError SKGSubOperationObject::getCategory(SKGCategoryObject& oCategory) const
 {
-    SKGError err = getDocument()->getObject("v_category", "id=" + getAttribute("r_category_id"), oCategory);
+    SKGError err = getDocument()->getObject("v_category", "id=" % getAttribute("r_category_id"), oCategory);
     return err;
 }
 
@@ -100,15 +110,15 @@ double SKGSubOperationObject::getQuantity() const
 }
 
 
-SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker)
+SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker, bool iForce)
 {
     SKGError err;
     SKGTrackerObject previous;
     getTracker(previous);
-    if(iTracker != previous) {
-        if(previous.isClosed()) {
+    if (iTracker != previous) {
+        if (!iForce && previous.isClosed()) {
             err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to remove an operation from a closed tracker"));
-        } else if(iTracker.isClosed()) {
+        } else if (!iForce && iTracker.isClosed()) {
             err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add an operation in a closed tracker"));
         } else {
             err = setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
@@ -120,8 +130,8 @@ SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker)
 SKGError SKGSubOperationObject::getTracker(SKGTrackerObject& oTracker) const
 {
     QString idS = getAttribute("r_refund_id");
-    if(idS.isEmpty()) idS = '0';
-    SKGError err = getDocument()->getObject("v_refund", "id=" + idS, oTracker);
+    if (idS.isEmpty()) idS = '0';
+    SKGError err = getDocument()->getObject("v_refund", "id=" % idS, oTracker);
     return err;
 
 }
