@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -59,7 +59,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGSubOperationObject& operator= (const SKGObjectBase &iObject);
+    virtual const SKGSubOperationObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
@@ -114,10 +114,11 @@ public:
     /**
      * Set the tracker
      * @param iTracker the tracker
+     * @param iForce force the change of the tracker even if closed
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setTracker(const SKGTrackerObject& iTracker);
+    virtual SKGError setTracker(const SKGTrackerObject& iTracker, bool iForce = false);
 
     /**
      * Get the tracker
@@ -141,6 +142,20 @@ public:
      */
     virtual double getQuantity() const;
 
+    /**
+     * Set the formula
+     * @param iFormula the formula
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setFormula(const QString& iFormula);
+
+    /**
+     * Get the formula
+     * @return the formula
+     */
+    virtual QString getFormula() const;
+
 };
 /**
  * Declare the class
