@@ -557,7 +557,8 @@ SKGError SKGUnitObject::getUnitValue(const QDate& iDate, SKGUnitValueObject& oUn
 double SKGUnitObject::getAmount(const QDate& iDate) const
 {
     double output = 0;
-    if (getDocument()) {
+    if (getType() == SKGUnitObject::PRIMARY) output = 1.0;
+    else if (getDocument()) {
         //Search result in cache
         QString ids = SKGServices::intToString(getID());
         QString dates = SKGServices::dateToSqlString(QDateTime(iDate));
@@ -1071,7 +1072,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
             //ALTERNATIVE MODE
             QString fileName = KStandardDirs().findResource("data", "skrooge/quotes/" % source % ".txt");
             if (fileName.isEmpty()) {
-                err = SKGError(ERR_FAIL, i18nc("Error message", "Source of download %1 not installed.", source));
+                err = SKGError(ERR_FAIL, i18nc("Error message", "Source of download %1 is not installed.", source));
             } else {
                 //Read source file
                 QHash< QString, QString > properties;
