@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -147,7 +147,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGUnitObject& operator= (const SKGObjectBase &iObject);
+    virtual const SKGUnitObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Set the symbol of this unit
@@ -163,6 +163,20 @@ public:
      */
     virtual QString getSymbol() const;
 
+    /**
+     * Set the download source of this unit
+     * @param iSource the download source ("" means native source)
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setDownloadSource(const QString& iSource);
+
+    /**
+     * Get the download source of this unit
+     * @return the download source ("" means native source)
+     */
+    virtual QString getDownloadSource() const;
+
     /**
      * Set the number of decimal of this unit
      * @param iNb number of decimal
@@ -254,14 +268,43 @@ public:
 
     /**
      * Download values
-     * @param iMode download mode
-     * @param iNbMaxValues nb max of values to download
-     * @param iAdditionalInfo to download additional information as property of the unit
+     * @param iMode download mode (used only for native source)
+     * @param iNbMaxValues nb max of values to download (used only for native source)
+     * @param iAdditionalInfo to download additional information as property of the unit (used only for native source)
      * @return an object managing the error
      *   @see SKGError
      */
     virtual SKGError downloadUnitValue(UnitDownloadMode iMode = LAST, int iNbMaxValues = 50, bool iAdditionalInfo = false);
 
+    /**
+     * Get the list of sources for the download
+     * @return the list of sources
+     */
+    static QStringList downloadSources();
+
+    /**
+     * Create a new source
+     * @param iNewSource the name of the new source
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    static SKGError addSource(const QString& iNewSource);
+
+    /**
+     * To know if a source can be modified or deleted
+     * @param iSource the name of the source to modified or deleted
+     * @return true or false
+     */
+    static bool isWritable(const QString& iSource);
+
+    /**
+     * Delete a new source
+     * @param iSource the name of the source to delete
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    static SKGError deleteSource(const QString& iSource);
+
     /**
      * Get amount of the unit at a date
      * @param iDate date
@@ -270,7 +313,7 @@ public:
     virtual double getAmount(const QDate& iDate = QDate::currentDate()) const;
 
     /**
-     * Get daily change in pourcentage at a date.
+     * Get daily change in percentage at a date.
      * @param iDate date
      * @return daily change
      */
@@ -325,6 +368,14 @@ public:
      */
     virtual SKGError merge(const SKGUnitObject& iUnit);
 
+    /**
+     * Remove all unit values not relevant.
+     * The curve is preserved but useless values are removed.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError simplify();
+
 protected:
     /**
      * Get where clause needed to identify objects.
