@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,8 +26,8 @@
 #include <kglobal.h>
 #include <klocale.h>
 
-SKGDateEdit::SKGDateEdit(QWidget *parent, const char *name)
-    : KPIM::KDateEdit(parent)
+SKGDateEdit::SKGDateEdit(QWidget* parent, const char* name)
+    : KPIM::KDateEdit(parent) //TODO: Migrate on KDateCombo
 {
     setObjectName(name);
     setMode(CURRENT);
