@@ -91,7 +91,7 @@ void SKGFilteredTableView::onFilterChanged()
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     //Update model
-    if (m_objectModel && m_objectModel->setFilter(ui.kShow->isEnabled() ? ui.kShow->getWhereClause() : "")) {
+    if (m_objectModel && ui.kShow->isEnabled() && m_objectModel->setFilter(ui.kShow->getWhereClause())) {
         m_objectModel->dataModified();
     }
 
