@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -37,10 +37,12 @@
 #include <QGraphicsSceneWheelEvent>
 #include <qmath.h>
 
-SKGGraphicsView::SKGGraphicsView(QWidget *parent)
+SKGGraphicsView::SKGGraphicsView(QWidget* parent)
     : QWidget(parent), m_oscale(1), m_toolBarVisible(true)
 {
     ui.setupUi(this);
+    setAntialiasing(true);
+
     graphicsView()->installEventFilter(this);
 
     //Set icons
@@ -64,6 +66,13 @@ SKGGraphicsView::SKGGraphicsView(QWidget *parent)
     connect(zoomMenu, SIGNAL(changed(int)), ui.kZoom, SLOT(setValue(int)));
     connect(ui.kZoom, SIGNAL(changed(int)), zoomMenu, SLOT(setValue(int)));
 
+    m_actShowToolBar = m_mainMenu->addAction(KIcon("show-menu"), i18nc("Noun, user action", "Show tool bar"));
+    if (m_actShowToolBar) {
+        m_actShowToolBar->setCheckable(true);
+        m_actShowToolBar->setChecked(true);
+        connect(m_actShowToolBar, SIGNAL(triggered(bool)), this, SLOT(onSwitchToolBarVisibility()));
+    }
+
     m_mainMenu->addSeparator();
 
     QAction* actCopy = m_mainMenu->addAction(ui.kCopy->icon(), ui.kCopy->toolTip());
@@ -75,24 +84,7 @@ SKGGraphicsView::SKGGraphicsView(QWidget *parent)
     QAction* actExport = m_mainMenu->addAction(KIcon("document-export"), i18nc("Noun, user action", "Export..."));
     connect(actExport, SIGNAL(triggered(bool)), this, SLOT(onExport()));
 
-    m_mainMenu->addSeparator();
-
-    m_actAntialiasing = m_mainMenu->addAction(KIcon("preference-desktop-display-color"), i18nc("Noun, user action", "Antialiasing"));
-    if(m_actAntialiasing) {
-        m_actAntialiasing->setCheckable(true);
-        m_actAntialiasing->setChecked(true);
-        onSwitchAntialiasing();
-        connect(m_actAntialiasing, SIGNAL(triggered(bool)), this, SLOT(onSwitchAntialiasing()));
-    }
-
-    connect(graphicsView(), SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(showMenu(const QPoint&)));
-
-    m_actShowToolBar = m_mainMenu->addAction(KIcon("show-menu"), i18nc("Noun, user action", "Show tool bar"));
-    if(m_actShowToolBar) {
-        m_actShowToolBar->setCheckable(true);
-        m_actShowToolBar->setChecked(true);
-        connect(m_actShowToolBar, SIGNAL(triggered(bool)), this, SLOT(onSwitchToolBarVisibility()));
-    }
+    connect(graphicsView(), SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showMenu(QPoint)));
 
     //Timer to refresh
     m_timer.setSingleShot(true);
@@ -101,16 +93,18 @@ SKGGraphicsView::SKGGraphicsView(QWidget *parent)
 
 SKGGraphicsView::~SKGGraphicsView()
 {
-    m_actAntialiasing = NULL;
     m_actShowToolBar = NULL;
     m_actZoomOriginal = NULL;
     m_mainMenu = NULL;
+    m_actAntialiasing = NULL;
+    m_actZoomOriginal = NULL;
+    m_actAntialiasing = NULL;
 }
 
-void SKGGraphicsView::setScene(QGraphicsScene * iScene)
+void SKGGraphicsView::setScene(QGraphicsScene* iScene)
 {
     graphicsView()->setScene(iScene);
-    if(iScene) iScene->installEventFilter(this);
+    if (iScene) iScene->installEventFilter(this);
     onZoom();
 }
 
@@ -127,7 +121,6 @@ QString SKGGraphicsView::getState() const
     doc.appendChild(root);
 
     root.setAttribute("isToolBarVisible", isToolBarVisible() ? "Y" : "N");
-    if(m_actAntialiasing) root.setAttribute("antialiasing", m_actAntialiasing->isChecked() ? "Y" : "N");
 
     return doc.toString();
 }
@@ -140,10 +133,7 @@ void SKGGraphicsView::setState(const QString& iState)
     QDomElement root = doc.documentElement();
 
     QString isToolBarVisible = root.attribute("isToolBarVisible");
-    QString antialiasing = root.attribute("antialiasing");
-
     setToolBarVisible(isToolBarVisible != "N");
-    if(m_actAntialiasing) m_actAntialiasing->setChecked(antialiasing != "N");
 }
 
 KMenu* SKGGraphicsView::getContextualMenu() const
@@ -153,14 +143,14 @@ KMenu* SKGGraphicsView::getContextualMenu() const
 
 void SKGGraphicsView::showMenu(const QPoint& pos)
 {
-    if(m_mainMenu) m_mainMenu->popup(graphicsView()->mapToGlobal(pos));
+    if (m_mainMenu) m_mainMenu->popup(graphicsView()->mapToGlobal(pos));
 }
 
 void SKGGraphicsView::setToolBarVisible(bool iVisibility)
 {
     m_toolBarVisible = iVisibility;
     ui.toolBar->setVisible(m_toolBarVisible);
-    if(m_actShowToolBar) m_actShowToolBar->setChecked(m_toolBarVisible);
+    if (m_actShowToolBar) m_actShowToolBar->setChecked(m_toolBarVisible);
 }
 
 bool SKGGraphicsView::isToolBarVisible() const
@@ -178,20 +168,20 @@ void SKGGraphicsView::onSwitchToolBarVisibility()
     setToolBarVisible(!isToolBarVisible());
 }
 
-void SKGGraphicsView::onSwitchAntialiasing()
+void SKGGraphicsView::setAntialiasing(bool iAntialiasing)
 {
-    if(m_actAntialiasing) graphicsView()->setRenderHint(QPainter::Antialiasing, m_actAntialiasing->isChecked());
+    graphicsView()->setRenderHint(QPainter::Antialiasing, iAntialiasing);
 }
 
-bool SKGGraphicsView::eventFilter(QObject *object, QEvent *event)
+bool SKGGraphicsView::eventFilter(QObject* object, QEvent* event)
 {
-    if(object == graphicsView()->scene()) {
+    if (object == graphicsView()->scene()) {
         QGraphicsSceneWheelEvent* e = dynamic_cast<QGraphicsSceneWheelEvent*>(event);
-        if(e && e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier) {
+        if (e && e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier) {
             int numDegrees = e->delta() / 8;
             int numTicks = numDegrees / 15;
 
-            if(numTicks > 0) {
+            if (numTicks > 0) {
                 ui.kZoom->zoomIn();
             } else {
                 ui.kZoom->zoomOut();
@@ -199,9 +189,9 @@ bool SKGGraphicsView::eventFilter(QObject *object, QEvent *event)
             e->setAccepted(true);
             return true;
         }
-    } else if(object == graphicsView() &&  event && event->type() == QEvent::Resize) {
+    } else if (object == graphicsView() &&  event && event->type() == QEvent::Resize) {
         Q_EMIT resized();
-        if(ui.kZoom->value() == ui.kZoom->resetValue()) m_timer.start(300);
+        if (ui.kZoom->value() == ui.kZoom->resetValue()) m_timer.start(300);
     }
     return QWidget::eventFilter(object, event);
 }
@@ -215,8 +205,8 @@ void SKGGraphicsView::onZoom()
 {
     _SKGTRACEIN(10, "SKGGraphicsView::onZoom");
     int sliderValue = ui.kZoom->value();
-    if(graphicsView()->scene()) {
-        if(sliderValue == -10) {
+    if (graphicsView()->scene()) {
+        if (sliderValue == -10) {
             graphicsView()->fitInView(graphicsView()->scene()->sceneRect(), Qt::KeepAspectRatio);
             m_oscale = 1;
         } else {
@@ -232,7 +222,7 @@ void SKGGraphicsView::onPrint()
     _SKGTRACEIN(10, "SKGGraphicsView::onPrint");
     QPrinter printer;
     QPointer<QPrintDialog> dialog = new QPrintDialog(&printer, this);
-    if(dialog->exec() == QDialog::Accepted) {
+    if (dialog->exec() == QDialog::Accepted) {
         QPainter painter(&printer);
         graphicsView()->render(&painter);
         painter.end();
@@ -244,16 +234,16 @@ void SKGGraphicsView::onExport()
 {
     _SKGTRACEIN(10, "SKGGraphicsView::onExport");
     QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "application/pdf image/svg+xml image/png image/jpeg image/gif image/tiff", this);
-    if(fileName.isEmpty()) return;
+    if (fileName.isEmpty()) return;
 
     QString extension = QFileInfo(fileName).suffix().toUpper();
-    if(extension == "PDF") {
+    if (extension == "PDF") {
         QPrinter printer;
         printer.setOutputFileName(fileName);
         QPainter painter(&printer);
         graphicsView()->render(&painter);
         painter.end();
-    } else if(extension == "SVG") {
+    } else if (extension == "SVG") {
         QSvgGenerator generator;
         generator.setFileName(fileName);
         generator.setSize(QSize(200, 200));
@@ -277,8 +267,8 @@ void SKGGraphicsView::onExport()
 void SKGGraphicsView::onCopy()
 {
     _SKGTRACEIN(10, "SKGGraphicsView::onCopy");
-    QClipboard *clipboard = QApplication::clipboard();
-    if(clipboard) {
+    QClipboard* clipboard = QApplication::clipboard();
+    if (clipboard) {
 
         QImage image(graphicsView()->size(), QImage::Format_ARGB32);
         QPainter painter(&image);
