@@ -75,15 +75,22 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
       m_tabWidget(new SKGTabWidget(this)),
       m_splashScreen(iSplashScreen),
       m_currentDocument(iDocument),
-      m_tipOfDayAction(NULL), m_closePageAction(NULL), m_closeAllPagesAction(NULL), m_closeAllOtherPagesAction(NULL),
+      m_tipOfDayAction(NULL), m_closePageAction(NULL), m_closeAllPagesAction(NULL), m_closeAllOtherPagesAction(NULL), m_switchPinState(NULL),
       m_fullScreenAction(NULL), m_actLock(NULL), m_actUnLock(NULL), m_kSystemTrayIcon(NULL),
       m_kNormalMessage(NULL), m_zoomSelector(NULL),  m_previousAction(NULL), m_nextAction(NULL), m_buttonMenuAction(NULL),
-      m_middleClick(false), m_saveOnClose(false)
+      m_mainWidget(NULL), m_mainLayout(NULL), m_middleClick(false), m_saveOnClose(false)
 {
     SKGTRACEIN(1, "SKGMainPanel::SKGMainPanel");
 
     //Set main panel
     m_mainPanel = this;
+    QWidget* w = new QWidget(this);
+    m_mainLayout = new QHBoxLayout(w);
+    m_mainLayout->setSpacing(0);
+    m_mainLayout->setContentsMargins(0, 0, 0, 0);
+    m_mainLayout->addWidget(m_tabWidget);
+
+    //setMainWidget(new QLabel("hello"));
 
     //Initialize settings
     KSharedConfigPtr config = KSharedConfig::openConfig();
@@ -207,7 +214,7 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     ui.setupUi(this);
 
     // tell the KXmlGuiWindow that this is indeed the main widget
-    setCentralWidget(m_tabWidget);
+    setCentralWidget(w);
 
     refreshTabPosition();
     m_tabWidget->setMovable(true);
@@ -603,6 +610,13 @@ void SKGMainPanel::setupActions()
     actionCollection()->addAction(QLatin1String("view_unlock"), m_actUnLock);
     connect(m_actUnLock, SIGNAL(triggered(bool)), this, SLOT(actionUnlockDocks()));
 
+    m_switchPinState = new KAction(KIcon("document-encrypt"), i18nc("Noun, user action", "Pin this page"), this);
+    actionCollection()->addAction(QLatin1String("tab_switchpin"), m_switchPinState);
+    //TODO m_switchPinState->setShortcut(Qt::ALT + Qt::Key_W);
+    connect(m_switchPinState, SIGNAL(triggered()), this, SLOT(switchPinPage()));
+
+    registerGlobalAction("tab_switchpin", m_switchPinState);
+
     //
     m_closePageAction = actionCollection()->addAction(KStandardAction::Close, "tab_close", this, SLOT(closePage()));
 
@@ -642,7 +656,7 @@ void SKGMainPanel::setupActions()
 
     //
     QStringList overlay;
-    overlay.push_back("rating");
+    overlay.push_back("bookmarks");
     m_overwriteBookmarkStateAction = new KAction(KIcon("document-save", NULL, overlay), i18nc("Noun, user action", "Overwrite bookmark state"), this);
     actionCollection()->addAction(QLatin1String("tab_overwritebookmark"), m_overwriteBookmarkStateAction);
     connect(m_overwriteBookmarkStateAction, SIGNAL(triggered()), this, SLOT(overwriteBookmarkState()));
@@ -730,6 +744,7 @@ void SKGMainPanel::setupActions()
         sep->setSeparator(true);
         m_tabWidget->insertAction(0, sep);
     }
+    m_tabWidget->insertAction(0, getGlobalAction("tab_switchpin"));
     m_tabWidget->insertAction(0, getGlobalAction("tab_resetdefaultstate"));
     m_tabWidget->insertAction(0, getGlobalAction("tab_savedefaultstate"));
     m_tabWidget->insertAction(0, getGlobalAction("tab_overwritebookmark"));
@@ -1045,6 +1060,7 @@ int SKGMainPanel::getNbSelectedObjects()
 
 SKGAdviceList SKGMainPanel::getAdvices() const
 {
+    SKGTRACEIN(1, "SKGMainPanel::getAdvices");
     //Get list of ignored advices
     QString currentMonth = QDate::currentDate().toString("yyyy-MM");
     QStringList ignoredAdvices = getDocument()->getParameters("advices", "t_value='I' OR t_value='I_" % currentMonth % '\'');
@@ -1233,6 +1249,11 @@ void SKGMainPanel::refresh()
 
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
+    //Show/hide main widget
+    bool atLeastOnePageOpened = (m_tabWidget->count() > 0);
+    m_tabWidget->setVisible(atLeastOnePageOpened);
+    if (m_mainWidget) m_mainWidget->setVisible(!atLeastOnePageOpened);
+
     //Refresh plugins
     int nb = m_pluginsList.count();
     for (int i = 0; i < nb; ++i) {
@@ -1240,15 +1261,18 @@ void SKGMainPanel::refresh()
     }
 
     //Enable addTabeAction
-    bool atLeastOnePageOpened = (m_tabWidget->count() > 0);
+    SKGTabPage* toSave = currentPage();
+    if (toSave && toSave->isPin()) {
+        m_switchPinState->setText(i18nc("Noun, user action", "Unpin this page"));
+    } else {
+        m_switchPinState->setText(i18nc("Noun, user action", "Pin this page"));
+    }
     m_addTabAction->setEnabled(atLeastOnePageOpened);
-    m_closePageAction->setEnabled(atLeastOnePageOpened);
+    m_closePageAction->setEnabled(atLeastOnePageOpened && !toSave->isPin());
     m_closeAllPagesAction->setEnabled(atLeastOnePageOpened);
     m_closeAllOtherPagesAction->setEnabled(m_tabWidget->count() > 1);
 
-    SKGTabPage* toSave = currentPage();
-    if (toSave)
-        if (m_saveDefaultStateAction) m_saveDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
+    if (m_saveDefaultStateAction) m_saveDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
     if (m_resetDefaultStateAction) m_resetDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
     if (m_overwriteBookmarkStateAction) m_overwriteBookmarkStateAction->setEnabled(toSave && !toSave->getBookmarkID().isEmpty());
     if (m_enableEditorAction) m_enableEditorAction->setEnabled(toSave && toSave->isEditor());
@@ -1329,13 +1353,18 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
     SKGTRACEIN(1, "SKGMainPanel::openPage");
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     bool previous = m_tabWidget->blockSignals(true);
+    //If the current page is pin, then open new page
+    SKGTabPage* cPage = currentPage();
+    if (cPage && cPage->isPin()) {
+        index = -1;
+        iSetCurrent = true;
+    }
+
     SKGTabPage* w = NULL;
 
     QList<SKGTabPage::SKGPageHistoryItem> previousPages;
-
     if (index != -1) {
         int currentIndex = currentPageIndex();
-        SKGTabPage* cPage = currentPage();
         if (currentIndex >= 0 && cPage) {
             previousPages = cPage->getPreviousPages();
             previousPages.insert(0, currentPageHistoryItem());
@@ -1383,6 +1412,12 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
         getDocument()->sendMessage(i18nc("An information message",  "Impossible to open the page because the plugin was not found"));
         notify(); //Due to sendMessage not in a transaction
     }
+
+    //Show/hide main widget
+    bool atLeastOnePageOpened = (m_tabWidget->count() > 0);
+    m_tabWidget->setVisible(atLeastOnePageOpened);
+    if (m_mainWidget) m_mainWidget->setVisible(!atLeastOnePageOpened);
+
     m_tabWidget->blockSignals(previous);
     if (iSetCurrent) Q_EMIT currentPageChanged();
     QApplication::restoreOverrideCursor();
@@ -1396,7 +1431,7 @@ int SKGMainPanel::currentPageIndex() const
 
 SKGTabPage* SKGMainPanel::currentPage() const
 {
-    return (SKGTabPage*) m_tabWidget->currentWidget();
+    return qobject_cast< SKGTabPage* >(m_tabWidget->currentWidget());
 }
 
 KSplashScreen* SKGMainPanel::splashScreen() const
@@ -1443,7 +1478,18 @@ void SKGMainPanel::onOpenContext(Qt::MouseButtons iMouse, Qt::KeyboardModifiers
     m_middleClick = false;
 }
 
-void SKGMainPanel::closePage(QWidget* iWidget)
+void SKGMainPanel::switchPinPage(QWidget* iWidget)
+{
+    SKGTabPage* toSwitch = qobject_cast< SKGTabPage* >(iWidget);
+    if (toSwitch == NULL)  toSwitch = currentPage();
+
+    if (toSwitch) {
+        toSwitch->setPin(!toSwitch->isPin());
+        Q_EMIT currentPageChanged();
+    }
+}
+
+void SKGMainPanel::closePage(QWidget* iWidget, bool iForce)
 {
     SKGTRACEIN(1, "SKGMainPanel::closePage");
     if (getDocument()->getCurrentTransaction()) {
@@ -1451,22 +1497,26 @@ void SKGMainPanel::closePage(QWidget* iWidget)
         KMessageBox::information(this, i18nc("Question", "A page cannot be closed when an operation is running."));
         QApplication::restoreOverrideCursor();
     } else {
-        QWidget* toRemove = iWidget;
-        if (toRemove == NULL)  toRemove = m_tabWidget->currentWidget();
-        if (toRemove) {
-            ((SKGTabPage*) toRemove)->close();
+        SKGTabPage* toRemove = qobject_cast< SKGTabPage* >(iWidget);
+        if (toRemove == NULL)  toRemove = currentPage();
+        if (toRemove && toRemove->close(iForce))
             delete toRemove;
-        }
     }
+
+    //Show/hide main widget
+    bool atLeastOnePageOpened = (m_tabWidget->count() > 0);
+    m_tabWidget->setVisible(atLeastOnePageOpened);
+    if (m_mainWidget) m_mainWidget->setVisible(!atLeastOnePageOpened);
 }
 
-void SKGMainPanel::closeAllPages()
+void SKGMainPanel::closeAllPages(bool iForce)
 {
     SKGTRACEIN(1, "SKGMainPanel::closeAllPages");
     bool previous = m_tabWidget->blockSignals(true);
     int nb = m_tabWidget->count();
     for (int i = nb - 1; i >= 0; --i) {
-        closePage(m_tabWidget->widget(i));
+        SKGTabPage* w = qobject_cast< SKGTabPage* >(m_tabWidget->widget(i));
+        if (w && (iForce || !w->isPin())) closePage(w);
     }
     m_tabWidget->blockSignals(previous);
     Q_EMIT currentPageChanged();
@@ -1477,12 +1527,12 @@ void SKGMainPanel::closeAllOtherPages(QWidget* iWidget)
     SKGTRACEIN(1, "SKGMainPanel::closeAllOtherPages");
     bool previous = m_tabWidget->blockSignals(true);
     QWidget* toKeep = iWidget;
-    if (toKeep == NULL)  toKeep = m_tabWidget->currentWidget();
+    if (toKeep == NULL)  toKeep = currentPage();
 
     int nb = m_tabWidget->count();
     for (int i = nb - 1; i >= 0; --i) {
-        QWidget* w = m_tabWidget->widget(i);
-        if (w != toKeep) closePage(w);
+        SKGTabPage* w = qobject_cast< SKGTabPage* >(m_tabWidget->widget(i));
+        if (w && w != toKeep && !w->isPin()) closePage(w);
     }
     m_tabWidget->blockSignals(previous);
     Q_EMIT currentPageChanged();
@@ -1492,7 +1542,7 @@ void SKGMainPanel::saveDefaultState()
 {
     SKGTRACEIN(1, "SKGMainPanel::saveDefaultState");
     SKGError err;
-    SKGTabPage* toSave = (SKGTabPage*) m_tabWidget->currentWidget();
+    SKGTabPage* toSave = currentPage();
     if (toSave) {
         //Get bookmarks uuid
         QString uuid = toSave->getBookmarkID();
@@ -1512,7 +1562,7 @@ void SKGMainPanel::overwriteBookmarkState()
 {
     SKGTRACEIN(1, "SKGMainPanel::overwriteBookmarkState");
     SKGError err;
-    SKGTabPage* toSave = (SKGTabPage*) m_tabWidget->currentWidget();
+    SKGTabPage* toSave = currentPage();
     if (toSave) {
         //Get bookmarks uuid
         QString uuid = toSave->getBookmarkID();
@@ -1527,7 +1577,7 @@ void SKGMainPanel::resetDefaultState()
 {
     SKGTRACEIN(1, "SKGMainPanel::resetDefaultState");
     SKGError err;
-    SKGTabPage* toSave = (SKGTabPage*) m_tabWidget->currentWidget();
+    SKGTabPage* toSave = currentPage();
     if (toSave) {
         QString name = toSave->getDefaultStateAttribute();
         if (!name.isEmpty()) {
@@ -1668,7 +1718,7 @@ void SKGMainPanel::onCancelCurrentAction()
 void SKGMainPanel::onQuitAction()
 {
     //Bug 2777697: To be sure that all page modifications are closed
-    closeAllPages();
+    closeAllPages(true);
     //Bug 2777697:
 
     qApp->closeAllWindows();
@@ -1810,4 +1860,21 @@ void SKGMainPanel::onZoomChanged()
     }
 }
 
+void SKGMainPanel::setMainWidget(QWidget* iWidget)
+{
+    if (m_mainWidget == NULL && m_mainLayout && iWidget) {
+        m_mainWidget = iWidget;
+        m_mainLayout->addWidget(m_mainWidget);
+
+        //Show/hide main widget
+        m_tabWidget->setVisible(m_tabWidget->count());
+        if (m_mainWidget) m_mainWidget->setVisible(!m_tabWidget->isVisible());
+    }
+}
+
+SKGTabWidget* SKGMainPanel::getTabWidget() const
+{
+    return m_tabWidget;
+}
+
 #include "skgmainpanel.moc"
