@@ -187,6 +187,18 @@ public Q_SLOTS:
      */
     virtual KSplashScreen* splashScreen() const;
 
+    /**
+     * Set the main widget
+     * @param iWidget the widget to display when all pages are closed
+     */
+    virtual void setMainWidget(QWidget* iWidget);
+
+    /**
+     * Get the tab widget.
+     * @return the tab widget
+     */
+    virtual SKGTabWidget* getTabWidget() const;
+
     /**
      * Get the history item of the current page
      * @return the history item
@@ -258,10 +270,17 @@ public Q_SLOTS:
     virtual SKGTabPage* openPage(SKGInterfacePlugin* plugin, int index = -1, const QString& parameters = "", const QString& title = "", const QString& iID = "", bool iSetCurrent = true);
 
     /**
-     * Close a page
+     * Switch the pin state of the page
      * @param iWidget the page to remove (NULL means current one)
      */
-    virtual void closePage(QWidget* iWidget = NULL);
+    virtual void switchPinPage(QWidget* iWidget = NULL);
+
+    /**
+     * Close a page
+     * @param iWidget the page to remove (NULL means current one)
+     * @param iForce to close pinned pages too
+     */
+    virtual void closePage(QWidget* iWidget = NULL, bool iForce = false);
 
     /**
      * Close all other pages
@@ -271,8 +290,9 @@ public Q_SLOTS:
 
     /**
      * Close all pages
+     * @param iForce to close pinned pages too
      */
-    virtual void closeAllPages();
+    virtual void closeAllPages(bool iForce = false);
 
     /**
      * Register a global action
@@ -412,6 +432,7 @@ private:
     KAction* m_closePageAction;
     KAction* m_closeAllPagesAction;
     KAction* m_closeAllOtherPagesAction;
+    KAction* m_switchPinState;
     KAction* m_saveDefaultStateAction;
     KAction* m_resetDefaultStateAction;
     KAction* m_overwriteBookmarkStateAction;
@@ -433,6 +454,8 @@ private:
     KMenu* m_previousMenu;
     KMenu* m_nextMenu;
     KMenu* m_buttonMenu;
+    QWidget* m_mainWidget;
+    QHBoxLayout* m_mainLayout;
 
     struct doublePointer {
         void* p1;
