@@ -27,13 +27,11 @@
 #include "kicon.h"
 
 SKGShow::SKGShow(QWidget* parent)
-    : QToolButton(parent), m_mode(OR), m_inTrigger(false)
+    : QToolButton(parent), m_mode(OR), m_inTrigger(false), m_displayTitle(true)
 {
     setPopupMode(QToolButton::InstantPopup);
     setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     setAutoRaise(true);
-    setText(i18n("Show"));
-    setIcon(KIcon("show-menu"));
 
     m_menu = new KMenu(this);
     setMenu(m_menu);
@@ -103,10 +101,9 @@ QString SKGShow::getTitle() const
 {
     QString wc;
     if (m_menu) {
-        QList<QAction*> actions = m_menu->actions();
-        int nb = actions.count();
+        int nb = m_actions.count();
         for (int i = 0; i < nb; ++i) {
-            QAction* act = actions.at(i);
+            QAction* act = m_actions.at(i);
             if (act && act->isChecked()) {
                 if (!wc.isEmpty()) wc += (m_mode == OR ? " + " : " , ");
                 wc += act->toolTip();
@@ -127,11 +124,9 @@ void SKGShow::setState(const QString& iState)
     if (m_menu) {
         QStringList itemsChecked = SKGServices::splitCSVLine(iState.isEmpty() ? m_defaultState : iState);
 
-        QList<QAction*> actions = m_menu->actions();
-        int nb = actions.count();
+        int nb = m_actions.count();
         for (int i = 0; i < nb; ++i) {
-            QAction* act = actions.at(i);
-            if (act) act->setChecked(itemsChecked.contains(act->data().toString()));
+            m_actions.at(i)->setChecked(itemsChecked.contains(m_actions.at(i)->data().toString()));
         }
 
         //Change tooltip
@@ -149,6 +144,7 @@ void SKGShow::clear()
     m_check_to_uncheck.clear();
     m_uncheck_to_uncheck.clear();
     m_actions.clear();
+    m_icons.clear();
     m_whereclause.clear();
     m_defaultState.clear();
     m_menu->clear();
@@ -159,6 +155,43 @@ int SKGShow::count()
     return m_check_to_check.count();
 }
 
+int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, const QString& iIcon, const QString& iWhereClose, const QString& iGroup)
+{
+    if (m_menu) {
+        QActionGroup* group = m_groups[iGroup];
+        if (!group) {
+            group = new QActionGroup(this);
+            m_groups[iGroup] = group;
+        }
+
+        QAction* act = m_menu->addAction(iText);
+        if (act) {
+            act->setToolTip(iText);
+            act->setIcon(KIcon(iIcon));
+            act->setData(iIdentifier);
+            act->setCheckable(true);
+
+            m_check_to_check[act] = "";
+            m_check_to_uncheck[act] = "";
+            m_uncheck_to_check[act] = "";
+            m_uncheck_to_uncheck[act] = "";
+            m_actions.push_back(act);
+            m_icons.push_back(iIcon);
+
+            m_whereclause[act] = iWhereClose;
+
+            connect(act, SIGNAL(toggled(bool)), this, SLOT(trigger()));
+
+            group->addAction(act);
+        }
+
+        show();
+
+        return (m_actions.count() - 1);
+    }
+    return -1;
+}
+
 int SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QString& iIcon,
                      const QString& iWhereClose,
                      const QString& iListIdToCheckWhenChecked ,
@@ -180,6 +213,7 @@ int SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QSt
             m_uncheck_to_check[act] = iListIdToCheckWhenUnchecked;
             m_uncheck_to_uncheck[act] = iListIdToUncheckWhenUnchecked;
             m_actions.push_back(act);
+            m_icons.push_back(iIcon);
 
             m_whereclause[act] = iWhereClose;
 
@@ -225,6 +259,7 @@ void SKGShow::trigger()
         m_inTrigger = true;
 
         //Apply rules
+        QStringList over;
         if (act->isChecked()) {
             {
                 //Check items
@@ -270,13 +305,53 @@ void SKGShow::trigger()
         //Change tooltip
         setToolTip(getTitle());
 
+        //Change icon
+        QStringList icons;
+        QString mainIcon;
+        if (m_menu) {
+            int nb = m_actions.count();
+            for (int i = 0; i < nb; ++i) {
+                QAction* act = m_actions.at(i);
+                if (act && act->isChecked()) {
+                    if (!m_icons.at(i).isEmpty()) {
+                        if (mainIcon.isEmpty()) mainIcon = m_icons.at(i);
+                        else icons.push_back(m_icons.at(i));
+                    } else {
+                        if (mainIcon.isEmpty()) mainIcon = "show-menu";
+                    }
+                }
+            }
+        }
+        if (mainIcon.isEmpty()) mainIcon = "show-menu";
+        setIcon(KIcon(mainIcon, NULL, icons));
+
         //Emit event
         m_timer.start(300);
 
+        //Change title
+        refreshTitle();
+
         m_inTrigger = false;
     }
 }
 
+bool SKGShow::getDisplayTitle()
+{
+    return m_displayTitle;
+}
+
+void SKGShow::setDisplayTitle(bool iDisplay)
+{
+    m_displayTitle = iDisplay;
+    refreshTitle();
+}
+
+void SKGShow::refreshTitle()
+{
+    if (m_displayTitle) setText(i18n("Show: %1", getTitle()));
+    else setText(i18n("Show"));
+}
+
 QAction* SKGShow::getAction(const QString& iIdentifier) const
 {
     QAction* output = NULL;
