@@ -30,6 +30,7 @@
 
 class KMenu;
 class QAction;
+class QActionGroup;
 
 /**
  * This file is a widget to select what to show
@@ -47,6 +48,11 @@ class SKGBASEGUI_EXPORT SKGShow : public QToolButton
      */
     Q_PROPERTY(OperatorMode mode READ getMode WRITE setMode);
 
+    /**
+     * Mode
+     */
+    Q_PROPERTY(bool displayTitle READ getDisplayTitle WRITE setDisplayTitle);
+
     /**
      * This enumerate defines type of operator
      */
@@ -102,6 +108,18 @@ public:
      */
     virtual void setDefaultState(const QString& iState);
 
+    /**
+     * Get the current display mode
+     * @return true of false
+     */
+    virtual bool getDisplayTitle();
+
+    /**
+     * Set the current display mode
+     * @param iDisplay true if you want to see the selected filter of false
+     */
+    virtual void setDisplayTitle(bool iDisplay);
+
     /**
      * Get the current where clause
      * @return a where clause string
@@ -149,6 +167,23 @@ public:
                         const QString& iListIdToUncheckWhenUnchecked = ""
                        );
 
+    /**
+     * @brief Add an item to the menu
+     *
+     * @param iIdentifier unique identifier of the item
+     * @param iText text
+     * @param iIcon icon Defaults to "".
+     * @param iWhereClose icon Defaults to "".
+     * @param iGroup the group of actions.
+     * @return the index of the new item
+     **/
+    virtual int addGroupedItem(const QString& iIdentifier,
+                               const QString& iText,
+                               const QString& iIcon = "",
+                               const QString& iWhereClose = "",
+                               const QString& iGroup = ""
+                              );
+
     /**
      * @brief Set the list of items to check when iIndex is checked
      *
@@ -206,19 +241,23 @@ private:
     Q_DISABLE_COPY(SKGShow);
 
     QString getTitle() const;
+    void refreshTitle();
 
     KMenu* m_menu;
     QTimer m_timer;
     QString m_defaultState;
     OperatorMode m_mode;
     bool m_inTrigger;
+    bool m_displayTitle;
 
     QList<QAction*> m_actions;
+    QStringList m_icons;
     QMap<QAction*, QString> m_check_to_check;
     QMap<QAction*, QString> m_uncheck_to_check;
     QMap<QAction*, QString> m_check_to_uncheck;
     QMap<QAction*, QString> m_uncheck_to_uncheck;
     QMap<QAction*, QString> m_whereclause;
+    QMap<QString, QActionGroup*> m_groups;
 };
 
 #endif // SKGSHOW_H
