@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -35,6 +35,7 @@ class SKGGraphicsScene;
 class KMenu;
 class QTimer;
 class QWidgetAction;
+class QGraphicsItem;
 
 /**
  * This file is a table with graph with more features
@@ -54,7 +55,8 @@ public:
                     POINT,
                     LINE,
                     STACKAREA,
-                    BUBBLE
+                    BUBBLE,
+                    STACKCOLUMNS
                    };
     /**
      * Additionel information to display
@@ -94,7 +96,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGTableWithGraph(QWidget *parent = 0);
+    SKGTableWithGraph(QWidget* parent = 0);
 
     /**
      * Default Destructor
@@ -127,10 +129,22 @@ public Q_SLOTS:
 
     /**
      * Returns the table.
-     * @return vertical table
+     * @return table
      */
     virtual QTableWidget* table() const;
 
+    /**
+     * Returns the graph.
+     * @return graph
+     */
+    virtual SKGGraphicsView* graph() const;
+
+    /**
+     * Returns the text report.
+     * @return text report
+     */
+    virtual SKGWebView* textReport() const ;
+
     /**
      * Set Data
      * @param iData the data
@@ -176,7 +190,7 @@ public Q_SLOTS:
     virtual void setGraphTypeSelectorVisible(bool iVisible);
 
     /**
-     * Get athe visibility of the graph type selector zone
+     * Get the visibility of the graph type selector zone
      * @return the visibility
      */
     virtual bool isGraphTypeSelectorVisible() const;
@@ -225,6 +239,89 @@ public Q_SLOTS:
      */
     virtual void setFilterVisibility(bool iVisibility) const;
 
+    /**
+     * Set the axis color
+     * @param iColor the color
+     */
+    virtual void setAxisColor(const QColor& iColor = Qt::gray);
+
+    /**
+     * Set the grid color
+     * @param iColor the color
+     */
+    virtual void setGridColor(const QColor& iColor = Qt::lightGray);
+
+    /**
+     * Set the min color
+     * @param iColor the color
+     */
+    virtual void setMinColor(const QColor& iColor = Qt::red);
+
+    /**
+     * Set the max color
+     * @param iColor the color
+     */
+    virtual void setMaxColor(const QColor& iColor = Qt::green);
+
+    /**
+     * Set the average color
+     * @param iColor the color
+     */
+    virtual void setAverageColor(const QColor& iColor = Qt::blue);
+
+    /**
+     * Set the tendency color
+     * @param iColor the color
+     */
+    virtual void setTendencyColor(const QColor& iColor = Qt::darkYellow);
+
+    /**
+     * Set the outline color
+     * @param iColor the color
+     */
+    virtual void setOutlineColor(const QColor& iColor = Qt::black);
+
+    /**
+     * Set the background color
+     * @param iColor the color
+     */
+    virtual void setBackgroundColor(const QColor& iColor = Qt::white);
+
+    /**
+     * Set the text color
+     * @param iColor the color
+     */
+    virtual void setTextColor(const QColor& iColor = Qt::black);
+
+    /**
+     * Set antialiasing
+     * @param iAntialiasing enabled or disabled
+     */
+    virtual void setAntialiasing(bool iAntialiasing = true);
+
+    /**
+     * Redraw the graph after some milliseconds
+     */
+    virtual void redrawGraphDelayed();
+
+    /**
+     * To know if the table is visible
+     * @return the visibility
+     */
+    virtual bool isTableVisible() const;
+
+    /**
+     * To know if the graph is visible
+     * @return the visibility
+     */
+    virtual bool isGraphVisible() const;
+
+    /**
+     * To know if the text report is visible
+     * @return the visibility
+     */
+    virtual bool isTextReportVisible() const;
+
 Q_SIGNALS:
     /**
      * Selection changed
@@ -248,7 +345,6 @@ private Q_SLOTS:
     void refresh();
     void redrawText();
     void redrawGraph();
-    void redrawGraphDelayed();
     void showMenu(const QPoint& pos);
 
 private:
@@ -257,10 +353,11 @@ private:
     double computeStepSize(double iRange, double iTargetSteps);
     void addArrow(const QPointF& iPeak, double iSize, double iArrowAngle = 45, double iDegree = 90);
     void addLegend(const QPointF& iPosition, double iSize, double iScaleText, double iMaxY);
+    QGraphicsItem* drawPoint(qreal iX, qreal iY, qreal iRadius, int iMode, const QBrush& iBrush);
     int getAverageColumnIndex() const;
     int getMinColumnIndex() const;
 
-    static bool listSort(const QStringList &s1, const QStringList &s2);
+    static bool listSort(const QStringList& s1, const QStringList& s2);
     static Qt::SortOrder m_sortOrder;
     static int m_sortColumn;
 
@@ -281,7 +378,7 @@ private:
     bool m_legendVisible;
     bool m_graphVisible;
     bool m_tableVisible;
-    bool m_testVisible;
+    bool m_textVisible;
     bool m_zeroVisible;
 
     KMenu* m_mainMenu;
@@ -301,6 +398,17 @@ private:
     QMap<QString, QColor> m_mapTitleColor;
     QMap<QTableWidgetItem*, QGraphicsItem*> m_mapItemGraphic;
 
+    QColor m_axisColor;
+    QColor m_backgroundColor;
+    QColor m_textColor;
+    QColor m_gridColor;
+    QColor m_minColor;
+    QColor m_maxColor;
+    QColor m_averageColor;
+    QColor m_tendencyColor;
+    QColor m_outlineColor;
+    QBrush m_NegativeColor;
+
     SKGComboBox* m_displayMode;
 };
 
