@@ -159,6 +159,18 @@ public:
      */
     static SKGTabPage* parentTabPage(QWidget* iWidget);
 
+    /**
+     * Get the pin status
+     * @return the pin status
+     */
+    virtual bool isPin() const;
+
+    /**
+     * Set the pin status
+     * @param iPin the pin status
+     */
+    virtual void setPin(bool iPin);
+
 Q_SIGNALS:
     /**
      * This signal must be launched when the selection is modified
@@ -168,9 +180,10 @@ Q_SIGNALS:
 public Q_SLOTS:
     /**
      * Closes this widget
+     * @param iForce to close pinned pages too
      * @return true if the widget was closed; otherwise returns false.
      */
-    virtual bool close();
+    virtual bool close(bool iForce = false);
 
 private:
     Q_DISABLE_COPY(SKGTabPage);
@@ -179,6 +192,7 @@ private:
     QList<SKGTabPage::SKGPageHistoryItem> m_previousPages;
     QList<SKGTabPage::SKGPageHistoryItem> m_nextPages;
     int m_fontOriginalPointSize;
+    bool m_pin;
 };
 /**
  * Declare the class
