@@ -121,13 +121,15 @@ void SKGTabWidget::onRefreshSaveIcon()
         if (save) {
             if (page->isOverwriteNeeded()) {
                 save->show();
-                if (page->getBookmarkID().isEmpty()) {
-                    save->setIcon(KIcon("document-save"));
-                } else {
-                    QStringList overlay;
-                    overlay.push_back("rating");
-                    save->setIcon(KIcon("document-save", NULL, overlay));
-                }
+                save->setEnabled(true);
+                QStringList overlay;
+                if (page->isPin()) overlay.push_back("document-encrypt");
+                if (!page->getBookmarkID().isEmpty()) overlay.push_back("bookmarks");
+                save->setIcon(KIcon("document-save", NULL, overlay));
+            } else if (page->isPin()) {
+                save->show();
+                save->setEnabled(false);
+                save->setIcon(KIcon("document-encrypt"));
             } else save->hide();
         }
 
