@@ -56,7 +56,7 @@
 
 SKGTreeView::SKGTreeView(QWidget* parent)
     : QTreeView(parent),
-      m_autoResize(true), m_actAutoResize(NULL),
+      m_autoResize(true), m_autoResizeDone(false), m_actAutoResize(NULL),
       m_document(NULL), m_textResizable(true),
       m_model(NULL), m_proxyModel(NULL),
       stickH(false), stickV(false)
@@ -256,7 +256,10 @@ void SKGTreeView::setState(const QString& iState)
         if (!columnsAutoResize.isEmpty()) {
             m_autoResize = (columnsAutoResize == "Y");
             header()->setResizeMode(m_autoResize ? QHeaderView::Fixed : QHeaderView::Interactive);
-            if (!m_autoResize)  m_timerDelayedResize.stop();
+            if (!m_autoResize) {
+                m_timerDelayedResize.stop();
+                m_autoResizeDone = false;
+            }
         }
 
         //Set sort
@@ -371,8 +374,6 @@ void SKGTreeView::setupHeaderMenu()
     SKGTRACEIN(10, "SKGTreeView::setupHeaderMenu");
     if (m_model && m_model->isRefreshBlocked()) return;
 
-    bool iRefreshColumnSize = !(sender() == header());
-
     setCornerWidget(NULL);
     if (m_model && m_headerMenu) {
         //Corner button on tables to show the contextual menu
@@ -392,13 +393,13 @@ void SKGTreeView::setupHeaderMenu()
         if (!m_model->getWhereClause().contains("ORDER BY")) {
             groupbymenu = m_headerMenu->addMenu(i18nc("Noun, Menu name", "Group by"));
             groupby = new QActionGroup(groupbymenu);
-            QAction* actNone = groupbymenu->addAction(i18nc("Noun, grouping option", "None"));
-            if (actNone) {
-                actNone->setIcon(KIcon("dialog-cancel"));
-                actNone->setCheckable(true);
-                actNone->setChecked(m_groupby == "");
-                actNone->setData("");
-                groupby->addAction(actNone);
+            m_actGroupByNone = groupbymenu->addAction(i18nc("Noun, grouping option", "None"));
+            if (m_actGroupByNone) {
+                m_actGroupByNone->setIcon(KIcon("dialog-cancel"));
+                m_actGroupByNone->setCheckable(true);
+                m_actGroupByNone->setChecked(m_groupby == "");
+                m_actGroupByNone->setData("");
+                groupby->addAction(m_actGroupByNone);
             }
             if (m_proxyModel) {
                 QAction* actSort = groupbymenu->addAction(i18nc("Noun, grouping option", "Sorted column"));
@@ -462,7 +463,7 @@ void SKGTreeView::setupHeaderMenu()
                 QString col = m_model->headerData(idx, Qt::Horizontal, Qt::UserRole).toString();
                 QStringList values = col.split('|');
 
-                if (iRefreshColumnSize) {
+                if (!m_autoResizeDone) {
                     if (values.count() > 1) hHeader->setSectionHidden(idx, values.at(1) == "N");
                     if (values.count() > 2) {
                         int s = SKGServices::stringToInt(values.at(2));
@@ -495,6 +496,7 @@ void SKGTreeView::setupHeaderMenu()
                     }
                 }
             }
+            m_autoResizeDone = true;
 
             //Span first column
             if (m_proxyModel) {
@@ -556,7 +558,10 @@ void SKGTreeView::switchAutoResize()
     m_autoResize = m_actAutoResize->isChecked();
     header()->setResizeMode(m_autoResize ? QHeaderView::Fixed : QHeaderView::Interactive);
     if (m_autoResize) resizeColumnsToContentsDelayed();
-    else m_timerDelayedResize.stop();
+    else {
+        m_timerDelayedResize.stop();
+        m_autoResizeDone = false;
+    }
 }
 
 void SKGTreeView::groupByChanged(QAction* iAction)
@@ -602,9 +607,10 @@ void SKGTreeView::showHideColumn()
         if (!hidden) resizeColumnToContents(idx);
 
         //If the group by attibute is hidden the the group is removed
-        if (hidden && m_model->getAttribute(idx) == m_model->getGroupBy()) m_model->setGroupBy("");
-
-        m_model->dataModified();
+        QString att = m_model->getAttribute(idx);
+        QString groupBy = m_model->getGroupBy();
+        if (hidden &&  att == groupBy) groupByChanged(m_actGroupByNone);
+        else m_model->dataModified();
     }
 }
 
@@ -630,7 +636,10 @@ void SKGTreeView::changeSchema()
         resetColumnsOrder();
 
         m_model->setSupportedAttributes(list);
+        bool tmp = m_autoResizeDone;
+        m_autoResizeDone = false;
         m_model->dataModified();
+        m_autoResizeDone = tmp;
         header()->setSortIndicator(0, Qt::AscendingOrder);
     }
 }
@@ -913,7 +922,7 @@ bool SKGTreeView::eventFilter(QObject* object, QEvent* event)
     if (object == this) {
         QKeyEvent* kevent = dynamic_cast<QKeyEvent*>(event);
         if (kevent) {
-            if (kevent->matches(QKeySequence::Copy)) {
+            if (kevent->matches(QKeySequence::Copy) && this->state() != QAbstractItemView::EditingState) {
                 copy();
                 if (event) event->accept();
                 return true; //stop the process
