@@ -284,6 +284,7 @@ private:
 
     KMenu* m_headerMenu;
     bool m_autoResize;
+    bool m_autoResizeDone;
     QAction* m_actAutoResize;
     KAction* m_actExpandAll;
     KAction* m_actCollapseAll;
@@ -303,6 +304,8 @@ private:
     SKGObjectModelBase* m_model;
     QSortFilterProxyModel* m_proxyModel;
 
+    QAction* m_actGroupByNone;
+
     SKGObjectBase::SKGListSKGObjectBase m_lastSelection;
 
     bool stickH;
