@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,9 +21,12 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include <kglobal.h>
-#include <QWidget>
 #include "skgbasegui_export.h"
+#include "skgobjectbase.h"
+
+#include <QWidget>
+
+#include <kglobal.h>
 class SKGDocument;
 
 /**
@@ -79,6 +82,32 @@ public:
      */
     virtual QWidget* getDragWidget();
 
+    /**
+     * Get the current selection
+     * MUST BE OVERWRITTEN
+     * @return selected objects
+     */
+    virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();
+
+    /**
+     * Get the first selected object
+     * @return first selected object
+     */
+    virtual SKGObjectBase getFirstSelectedObject();
+
+    /**
+     * Get the number of seleted object
+     * CAN BE OVERWRITTEN FOR OPTIMIZATION
+     * @return number of selected objects
+     */
+    virtual int getNbSelectedObjects();
+
+    /**
+     * Get the main widget
+     * @return a widget
+     */
+    virtual QWidget* mainWidget() const;
+
 private:
     Q_DISABLE_COPY(SKGWidget);
 
