@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -35,10 +35,11 @@
 #include "skgzoomselectordesignerplugin.h"
 #include "skgshowdesignerplugin.h"
 #include "skgfilteredtableviewdesignerplugin.h"
+#include "skgwidgetselectordesignerplugin.h"
 
 #include <QtPlugin>
 
-SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject *parent)
+SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject* parent)
     : QObject(parent)
 {
     m_widgets.append(new SKGCalculatorEditDesignerPlugin(this));
@@ -55,6 +56,7 @@ SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject *pa
     m_widgets.append(new SKGTabWidgetDesignerPlugin(this));
     m_widgets.append(new SKGTableWidgetDesignerPlugin(this));
     m_widgets.append(new SKGWebViewDesignerPlugin(this));
+    m_widgets.append(new SKGWidgetSelectorDesignerPlugin(this));
     m_widgets.append(new SKGZoomSelectorDesignerPlugin(this));
 }
 
