@@ -35,6 +35,7 @@ class QSqlDatabase;
 class SKGObjectBase;
 class SKGError;
 class SKGPropertyObject;
+class SKGReport;
 
 /**
 * This class manages skg documents
@@ -155,6 +156,12 @@ public Q_SLOTS:
      */
     virtual QString getUniqueIdentifier();
 
+    /**
+     * Get database identifier
+     * @return the database identifier
+     */
+    virtual QString getDatabaseIdentifier();
+
     /**
      * Call the progress callstack.
      * @param iPosition the position in the current transaction.
@@ -519,6 +526,30 @@ public Q_SLOTS:
      */
     virtual SKGServices::AttributeType getAttributeType(const QString& iAttributeName) const;
 
+    /**
+     * Get unit. WARNING: This value can be not uptodated in a transaction.
+     * @param iPrefixInCache the prefix of the unit in the cache
+     * @return unit.
+     */
+    virtual SKGServices::SKGUnitInfo getUnit(const QString& iPrefixInCache);
+
+    /**
+     * Get formated money
+     * @param iValue value
+     * @param iUnit unit
+     * @param iHtml colored output
+     * @return formated value in red or black
+     */
+    virtual QString formatMoney(double iValue, SKGServices::SKGUnitInfo iUnit, bool iHtml = true) const;
+
+    /**
+     * Get formated percentage
+     * @param iValue value
+     * @param iInvertColors to set positive value in red and negative values in green
+     * @return formated value in red or black
+     */
+    virtual QString formatPercentage(double iValue, bool iInvertColors = false) const;
+
     /**
      * Add a value in the cache. Cache is cleaned after each transaction
      * @param iKey the key
@@ -724,6 +755,13 @@ public Q_SLOTS:
      */
     virtual SKGError getAttributesList(const QString& iTable, QStringList& oResult) const;
 
+    /**
+     * Get the report
+     * Do not forget to delete the pointer
+     * @return the report
+     */
+    virtual SKGReport* getReport();
+
 Q_SIGNALS:
     /**
      * This signal is launched by endTransaction on all tables modified when a huge modification occures on the model
