@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -66,7 +66,7 @@ SKGObjectBase::SKGObjectBase(SKGDocument* iDocument, const QString& iTable, int
     d->id = iID;
     d->table = iTable;
     d->document = iDocument;
-    if(d->id != 0) load();
+    if (d->id != 0) load();
 }
 
 SKGObjectBase::~SKGObjectBase()
@@ -80,7 +80,7 @@ SKGObjectBase::SKGObjectBase(const SKGObjectBase& iObject)
     copyFrom(iObject);
 }
 
-const SKGObjectBase& SKGObjectBase::operator= (const SKGObjectBase & iObject)
+const SKGObjectBase& SKGObjectBase::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -112,7 +112,7 @@ bool SKGObjectBase::operator>(const SKGObjectBase& iObject) const
 
 QString SKGObjectBase::getUniqueID() const
 {
-    return SKGServices::intToString(d->id) + '-' + getRealTable();
+    return SKGServices::intToString(d->id) % '-' % getRealTable();
 }
 
 int SKGObjectBase::getID() const
@@ -126,10 +126,10 @@ QString SKGObjectBase::getDisplayName() const
 
     SKGStringListList result;
     QString wc = getWhereclauseId();
-    if(wc.isEmpty()) wc = "id=" + SKGServices::intToString(d->id);
-    QString sql = "SELECT t_displayname FROM v_" + getRealTable() + "_displayname WHERE " + wc;
-    if(getDocument()) getDocument()->executeSelectSqliteOrder(sql, result);
-    if(result.count() == 2) output = result.at(1).at(0);
+    if (wc.isEmpty()) wc = "id=" % SKGServices::intToString(d->id);
+    QString sql = "SELECT t_displayname FROM v_" % getRealTable() % "_displayname WHERE " % wc;
+    if (getDocument()) getDocument()->executeSelectSqliteOrder(sql, result);
+    if (result.count() == 2) output = result.at(1).at(0);
 
     return output;
 }
@@ -145,7 +145,7 @@ void SKGObjectBase::copyFrom(const SKGObjectBase& iObject)
 SKGObjectBase SKGObjectBase::cloneInto(SKGDocument* iDocument)
 {
     SKGDocument* targetDocument = iDocument;
-    if(targetDocument == NULL) targetDocument = d->document;
+    if (targetDocument == NULL) targetDocument = d->document;
 
     SKGObjectBase output;
     output.copyFrom(*this);
@@ -191,11 +191,11 @@ SKGError SKGObjectBase::setAttributes(const QStringList& iNames, const QStringLi
 {
     SKGError err;
     int nb = iNames.size();
-    for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+    for (int i = 0; !err && i < nb; ++i) {
         QString att = iNames.at(i);
         QString val = iValues.at(i);
 
-        if(att != "id") err = setAttribute(att, val);
+        if (att != "id") err = setAttribute(att, val);
         else  d->id = SKGServices::stringToInt(val);
     }
     return err;
@@ -204,20 +204,20 @@ SKGError SKGObjectBase::setAttributes(const QStringList& iNames, const QStringLi
 SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue)
 {
     SKGError err;
-    if(iValue != NOUPDATE) {
+    if (iValue != NOUPDATE) {
         QString val = iValue;
 
         //Case modification on pointed document
-        if(this->getRealTable() == this->getTable() && iName != iName.toLower()) {
+        if (this->getRealTable() == this->getTable() && iName != iName.toLower()) {
             QString realAttribute = d->document->getRealAttribute(iName);
-            if(!realAttribute.isEmpty()) {
+            if (!realAttribute.isEmpty()) {
                 QStringList l = realAttribute.split('.');
-                if(l.size() == 3) {
+                if (l.size() == 3) {
                     SKGObjectBase obj;
                     QString refId = getAttribute(l.at(1));
-                    if(!refId.isEmpty()) {
-                        err = getDocument()->getObject("v_" + l.at(0), "id=" + refId, obj);
-                        if(err.isSucceeded()) {
+                    if (!refId.isEmpty()) {
+                        err = getDocument()->getObject("v_" % l.at(0), "id=" % refId, obj);
+                        if (!err) {
                             err = obj.setAttribute(l.at(2), iValue);
                             d->objects.push_back(obj);
                         }
@@ -226,14 +226,14 @@ SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue
             }
         }
         //Case modificator
-        else if(iValue.startsWith(QLatin1String("="))) {
+        else if (iValue.startsWith(QLatin1String("="))) {
             QString op = iValue.right(iValue.length() - 1).toLower();
             val = d->attributes[iName];
-            if(op == i18nc("Key word to modify a string into a field", "lower")) val = val.toLower();
-            else if(op == i18nc("Key word to modify a string into a field", "upper")) val = val.toUpper();
-            else if(op == i18nc("Key word to modify a string into a field", "capwords")) val = KStringHandler::capwords(val);
-            else if(op == i18nc("Key word to modify a string into a field", "capitalize")) val = val.left(1).toUpper() + val.right(val.length() - 1).toLower();
-            else if(op == i18nc("Key word to modify a string into a field", "trim")) val = val.trimmed();
+            if (op == i18nc("Key word to modify a string into a field", "lower")) val = val.toLower();
+            else if (op == i18nc("Key word to modify a string into a field", "upper")) val = val.toUpper();
+            else if (op == i18nc("Key word to modify a string into a field", "capwords")) val = KStringHandler::capwords(val);
+            else if (op == i18nc("Key word to modify a string into a field", "capitalize")) val = val.left(1).toUpper() % val.right(val.length() - 1).toLower();
+            else if (op == i18nc("Key word to modify a string into a field", "trim")) val = val.trimmed();
             else val = iValue;
         }
         d->attributes[iName] = val;
@@ -244,16 +244,16 @@ SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue
 QString SKGObjectBase::getAttribute(const QString& iName) const
 {
     QString output;
-    if(d->attributes.contains(iName)) {
+    if (d->attributes.contains(iName)) {
         output = d->attributes[iName];
     } else {
         //Is the iName a number ?
         bool ok;
         int pos = iName.toInt(&ok);
-        if(ok) {
+        if (ok) {
             //What is the key corresponding to this name ?
             QStringList keys = d->attributes.keys();
-            if(pos >= 0 && pos < keys.count()) output = d->attributes[keys[pos]];
+            if (pos >= 0 && pos < keys.count()) output = d->attributes[keys[pos]];
         }
     }
 
@@ -266,11 +266,11 @@ bool SKGObjectBase::exist() const
 
     SKGStringListList result;
     QString wc = getWhereclauseId();
-    if(wc.isEmpty() && d->id) wc = "id=" + SKGServices::intToString(d->id);
-    if(wc.isEmpty()) return false;
+    if (wc.isEmpty() && d->id) wc = "id=" % SKGServices::intToString(d->id);
+    if (wc.isEmpty()) return false;
 
-    QString sql = "SELECT count(1) FROM " + d->table + " WHERE " + wc;
-    if(getDocument()) getDocument()->executeSelectSqliteOrder(sql, result);
+    QString sql = "SELECT count(1) FROM " % d->table % " WHERE " % wc;
+    if (getDocument()) getDocument()->executeSelectSqliteOrder(sql, result);
     return (result.size() >= 2 && result.at(1).at(0) != "0");
 }
 
@@ -279,20 +279,20 @@ SKGError SKGObjectBase::load()
     SKGError err;
     SKGTRACEINRC(20, "SKGObjectBase::load", err);
 
-    if(getDocument()) {
+    if (getDocument()) {
         //Prepare where clause
         QString wc = getWhereclauseId();
-        if(wc.isEmpty()) wc = "id=" + SKGServices::intToString(d->id);
+        if (wc.isEmpty()) wc = "id=" % SKGServices::intToString(d->id);
 
         //Execute sql order
         SKGStringListList result;
-        err = getDocument()->executeSelectSqliteOrder("SELECT * FROM " + d->table + " WHERE " + wc, result);
-        if(err.isSucceeded()) {
+        err = getDocument()->executeSelectSqliteOrder("SELECT * FROM " % d->table % " WHERE " % wc, result);
+        if (!err) {
             int size = result.size();
-            if(size == 1)  err = SKGError(ERR_INVALIDARG, i18nc("Error message: Could not load something because it is not in the database", "Load of '%1' with '%2' failed because it was not found in the database", d->table, wc));
-            else if(size != 2)  err = SKGError(ERR_INVALIDARG, i18np("Load of '%2' with '%3' failed because of bad size of result (found one object)",
-                                                   "Load of '%2' with '%3' failed because of bad size of result (found %1 objects)",
-                                                   size - 1, d->table, wc));
+            if (size == 1)  err = SKGError(ERR_INVALIDARG, i18nc("Error message: Could not load something because it is not in the database", "Load of '%1' with '%2' failed because it was not found in the database", d->table, wc));
+            else if (size != 2)  err = SKGError(ERR_INVALIDARG, i18np("Load of '%2' with '%3' failed because of bad size of result (found one object)",
+                                                    "Load of '%2' with '%3' failed because of bad size of result (found %1 objects)",
+                                                    size - 1, d->table, wc));
             else {
                 SKGStringListListIterator itrow = result.begin();
                 QStringList columns = *(itrow);
@@ -309,7 +309,7 @@ SKGError SKGObjectBase::load()
 QString SKGObjectBase::getWhereclauseId() const
 {
     int id = getID();
-    if(id != 0) return "id=" + SKGServices::intToString(id);
+    if (id != 0) return "id=" % SKGServices::intToString(id);
     return "";
 }
 
@@ -318,18 +318,18 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
     SKGError err;
     SKGTRACEINRC(20, "SKGObjectBase::save", err);
 
-    if(!d->document) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
+    if (!d->document) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
     else {
         //Save linking objects
         int nb = d->objects.count();
-        for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+        for (int i = 0; !err && i < nb; ++i) {
             SKGObjectBase ref = d->objects.at(i);
             err = ref.save(iInsertOrUpdate, iReloadAfterSave);
         }
 
         //Check if we are in a transaction
-        if(err.isSucceeded()) err = d->document->checkExistingTransaction();
-        if(err.isSucceeded()) {
+        if (!err) err = d->document->checkExistingTransaction();
+        if (!err) {
             //Table to use
             QString tablename = getRealTable();
 
@@ -339,50 +339,50 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
             QString partUpdate;
 
             SKGQStringQStringMapIterator it;
-            for(it = d->attributes.begin() ; it != d->attributes.end(); ++it) {
+            for (it = d->attributes.begin() ; it != d->attributes.end(); ++it) {
                 QString att = SKGServices::stringToSqlString(it.key());
                 QString attlower = att.toLower();
-                if(att.length() > 2 && att == attlower) {  //We must ignore attributes coming from views
-                    QString value = '\'' + SKGServices::stringToSqlString(it.value()) + '\'';
+                if (att.length() > 2 && att == attlower) { //We must ignore attributes coming from views
+                    QString value = '\'' % SKGServices::stringToSqlString(it.value()) % '\'';
 
-                    if(!part1Insert.isEmpty()) {
+                    if (!part1Insert.isEmpty()) {
                         part1Insert.append(',');
                         part2Insert.append(',');
                         partUpdate.append(',');
                     }
                     //Attribute
-                    part1Insert.append('\'' + att + '\'');
+                    part1Insert.append('\'' % att % '\'');
 
                     //Value
                     part2Insert.append(value);
 
                     //Attribute=Value for update
-                    partUpdate.append(att + '=' + value);
+                    partUpdate.append(att % '=' % value);
                 }
             }
 
             //We try an Insert
-            if(d->id == 0) {
+            if (d->id == 0) {
                 //We have to try un insert
-                err = getDocument()->executeSqliteOrder("INSERT INTO " + tablename + " (" + part1Insert + ") VALUES (" + part2Insert + ')', &(d->id));
+                err = getDocument()->executeSqliteOrder("INSERT INTO " % tablename % " (" % part1Insert % ") VALUES (" % part2Insert % ')', &(d->id));
             } else {
                 //We must try an update
                 err = SKGError(ERR_ABORT, ""); //Just to go in UPDATE code
             }
 
-            if(err.isFailed() && iInsertOrUpdate) {
+            if (err && iInsertOrUpdate) {
                 //INSERT failed, could we try an update ?
                 QString wc = this->getWhereclauseId();
-                if(!wc.isEmpty()) {
+                if (!wc.isEmpty()) {
                     //Yes ==> Update
-                    err = getDocument()->executeSqliteOrder("UPDATE " + tablename + " SET " + partUpdate + " WHERE " + wc);
+                    err = getDocument()->executeSqliteOrder("UPDATE " % tablename % " SET " % partUpdate % " WHERE " % wc);
                 }
             }
         }
     }
 
     //Reload object is updated
-    if(err.isSucceeded() && iReloadAfterSave) {
+    if (!err && iReloadAfterSave) {
         //The object has been updated ==>load
         err = load();
     }
@@ -394,31 +394,31 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
 {
     SKGError err;
     SKGTRACEINRC(20, "SKGObjectBase::remove", err);
-    if(!d->document) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
+    if (!d->document) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
     else {
         //Check if we are in a transaction
         err = d->document->checkExistingTransaction();
 
         //delete order
-        QString viewForDelete = QString("v_") + getRealTable() + "_delete";
+        QString viewForDelete = QString("v_") % getRealTable() % "_delete";
 
         //Check if the delete view exist
         SKGStringListList temporaryResult;
-        d->document->executeSelectSqliteOrder("PRAGMA table_info( " + viewForDelete + " );", temporaryResult);
-        if(!iForce && temporaryResult.count() > 1) {  //At least one attribute
+        d->document->executeSelectSqliteOrder("PRAGMA table_info( " % viewForDelete % " );", temporaryResult);
+        if (!iForce && temporaryResult.count() > 1) { //At least one attribute
             //Delete view exists, check if the delete is authorized
-            err = d->document->executeSelectSqliteOrder("SELECT t_delete_message FROM " + viewForDelete + " WHERE id=" + SKGServices::intToString(d->id), temporaryResult);
-            if(err.isSucceeded()) {
+            err = d->document->executeSelectSqliteOrder("SELECT t_delete_message FROM " % viewForDelete % " WHERE id=" % SKGServices::intToString(d->id), temporaryResult);
+            if (!err) {
                 QString msg;
-                if(temporaryResult.count() > 1) msg = temporaryResult.at(1).at(0);
+                if (temporaryResult.count() > 1) msg = temporaryResult.at(1).at(0);
                 // Should the string below be translated ??? It contains no word
-                if(!msg.isEmpty()) err = SKGError(ERR_FORCEABLE, i18nc("Error message for an object", "'%1': %2", getDisplayName(), msg));
+                if (!msg.isEmpty()) err = SKGError(ERR_FORCEABLE, i18nc("Error message for an object", "'%1': %2", getDisplayName(), msg));
             }
         }
 
         QString displayname = getDisplayName(); //Must be done before the delete order
-        if(err.isSucceeded()) err = d->document->executeSqliteOrder("DELETE FROM " + getRealTable() + " WHERE id=" + SKGServices::intToString(d->id));
-        if(iSendMessage && err.isSucceeded() && !displayname.isEmpty())
+        if (!err) err = d->document->executeSqliteOrder("DELETE FROM " % getRealTable() % " WHERE id=" % SKGServices::intToString(d->id));
+        if (iSendMessage && !err && !displayname.isEmpty())
             err = d->document->sendMessage(i18nc("An information to the user that something was deleted", "'%1' has been deleted", displayname), false);
     }
 
@@ -432,7 +432,7 @@ SKGError SKGObjectBase::dump()
     //dump
     SKGTRACE << "=== START DUMP [" << getUniqueID() << "]===" << endl;
     SKGQStringQStringMapIterator it;
-    for(it = d->attributes.begin() ; it != d->attributes.end(); ++it)
+    for (it = d->attributes.begin() ; it != d->attributes.end(); ++it)
         SKGTRACE << it.key() << "=[" << it.value() << ']' << endl;
     SKGTRACE << "=== END DUMP [" << getUniqueID() << "]===" << endl;
     return err;
@@ -440,27 +440,27 @@ SKGError SKGObjectBase::dump()
 
 QStringList SKGObjectBase::getProperties() const
 {
-    return getDocument()->getParameters(getUniqueID());
+    return !getDocument() ? QStringList() : getDocument()->getParameters(getUniqueID());
 }
 
 QString SKGObjectBase::getProperty(const QString& iName) const
 {
-    return getDocument()->getParameter(iName, getUniqueID());
+    return !getDocument() ? QString() : getDocument()->getParameter(iName, getUniqueID());
 }
 
 QVariant SKGObjectBase::getPropertyBlob(const QString& iName) const
 {
-    return getDocument()->getParameterBlob(iName, getUniqueID());
+    return !getDocument() ? QVariant() : getDocument()->getParameterBlob(iName, getUniqueID());
 }
 
 SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QString& iFileName, SKGPropertyObject* oObjectCreated) const
 {
-    return getDocument()->setParameter(iName, iValue, iFileName, getUniqueID(), oObjectCreated);
+    return !getDocument() ? SKGError() : getDocument()->setParameter(iName, iValue, iFileName, getUniqueID(), oObjectCreated);
 }
 
 SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob, SKGPropertyObject* oObjectCreated) const
 {
-    return getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
+    return!getDocument() ? SKGError() :  getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
 
 }
 
