@@ -173,7 +173,7 @@ double SKGServices::stringToDouble(const QString& iNumber)
 {
     if (iNumber.isEmpty()) return 0;
     QString number = iNumber;
-    number.remove(' '); //To be able to convert something like "2 150,10"
+    number.remove(QRegExp("[^0-9-+eE,.]"));
 
     bool ok;
     double output = number.toDouble(&ok);
@@ -1045,6 +1045,45 @@ double SKGServices::getMicroTime()
 #endif
 }
 
+SKGStringListList SKGServices::getBase100Table(const SKGStringListList& iTable)
+{
+    SKGTRACEIN(10, "SKGServices::getBase100Table");
+
+    //Build history
+    SKGStringListList output;
+
+    output.push_back(iTable.at(0));
+
+    QStringList newLine;
+    int nblines = iTable.count();
+    int nbCols = 0;
+    if (nblines) {
+        nbCols = iTable.at(0).count();
+    }
+
+    //Create table
+    for (int i = 1; i < nblines; ++i) {
+        QStringList newLine;
+        newLine.push_back(iTable.at(i).at(0));
+
+        double valInitial = 0;
+
+        for (int j = 1; j < nbCols; ++j) {
+            double val = SKGServices::stringToDouble(iTable.at(i).at(j));
+            if (j == 1) {
+                valInitial = val;
+                val = 100.0;
+            } else {
+                if (valInitial != 0.0)val = 100.0 * val / valInitial;
+            }
+            newLine.push_back(SKGServices::doubleToString(val));
+        }
+        output.push_back(newLine);
+    }
+
+    return output;
+}
+
 SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable, bool iOfColumns, bool iAbsolute)
 {
     SKGTRACEIN(10, "SKGServices::getPercentTable");
