@@ -440,7 +440,6 @@ public:
      */
     static int SKGSqlTraces;
 
-
     /**
      * Create a table with all values expressed in % of the column
      * @param iTable table
@@ -450,6 +449,13 @@ public:
      */
     static SKGStringListList getPercentTable(const SKGStringListList& iTable, bool iOfColumns = true, bool iAbsolute = false);
 
+    /**
+     * Create a table in base 100
+     * @param iTable table
+     * @return the table
+     */
+    static SKGStringListList getBase100Table(const SKGStringListList& iTable);
+
     /**
      * Create an historized table.
      * Each column is the sum of previous ones
