@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,12 +32,12 @@
   * To generate a colorized string
   */
 #define COLORED(TEXT) \
-    "\x1b[3"+QString::number(1+(((SKGTraces::SKGIndentTrace.count()-2)/2)%7))+'m'+TEXT+"\x1b[39m"
+    "\x1b[3"%QString::number(1+(((SKGTraces::SKGIndentTrace.count()-2)/2)%7))%'m'%TEXT%"\x1b[39m"
 /**
   * To generate a red string
   */
 #define COLOREDRED(TEXT) \
-    QString("\x1b[31m")+TEXT+"\x1b[39m"
+    QString("\x1b[31m")%TEXT%"\x1b[39m"
 
 //===================================================================
 int SKGTraces::SKGLevelTrace = SKGServices::stringToInt(SKGServices::getenv("SKGTRACE"));
@@ -55,11 +55,11 @@ SKGTraces::SKGTraces(int iLevel, const QString& iName, SKGError* iRC)
         m_rc = iRC;
         SKGIndentTrace += "  ";
 
-        SKGTRACE << COLORED('>' + m_mame) << endl;
+        SKGTRACE << COLORED('>' % m_mame) << endl;
     }
     else m_output = false;
 
-    if(SKGPerfo) {
+    if (SKGPerfo) {
         m_profiling = true;
         m_mame = iName;
 
@@ -78,7 +78,7 @@ SKGTraces::SKGTraces(int iLevel, const QString& iName, SKGError* iRC)
 
         //Searching the key in the map
         m_it = SKGTraces::m_SKGPerfoMethode.find(m_mame);
-        if(m_it == SKGTraces::m_SKGPerfoMethode.end()) {
+        if (m_it == SKGTraces::m_SKGPerfoMethode.end()) {
             //Not found ==> initialisation
             SKGPerfoInfo init;
             init.NbCall = 0;
@@ -102,7 +102,7 @@ SKGTraces::SKGTraces(int iLevel, const QString& iName, SKGError* iRC)
 SKGTraces::~SKGTraces()
 {
     //Get delta time
-    if(m_elapse >= 0) {
+    if (m_elapse >= 0) {
 #ifdef Q_OS_WIN
         m_elapse = static_cast<double>(GetTickCount());
 #else
@@ -113,12 +113,12 @@ SKGTraces::~SKGTraces()
 #endif
     }
 
-    if(m_output) {
-        SKGTRACESUITE << SKGTraces::SKGIndentTrace << COLORED('<' + m_mame);
-        if(m_rc) {
-            SKGTRACESUITE << (m_rc->isSucceeded() ? COLORED(" RC=" + m_rc->getFullMessage()) : COLOREDRED(" RC=" + m_rc->getFullMessage()));
+    if (m_output) {
+        SKGTRACESUITE << SKGTraces::SKGIndentTrace << COLORED('<' % m_mame);
+        if (m_rc) {
+            SKGTRACESUITE << (m_rc->isSucceeded() ? QString(COLORED(" RC=" % m_rc->getFullMessage())) : QString(COLOREDRED(" RC=" % m_rc->getFullMessage())));
         }
-        if(m_profiling) {
+        if (m_profiling) {
             SKGTRACESUITE << " TIME=" << m_elapse << " ms";
         }
         SKGTRACESUITE << endl;
@@ -127,26 +127,26 @@ SKGTraces::~SKGTraces()
         m_rc = NULL;
     }
 
-    if(m_profiling) {
+    if (m_profiling) {
         //Update values
         ++ (m_it.value().NbCall);
         m_it.value().Time += m_elapse;
         m_it.value().TimePropre += m_elapse;
-        if(m_elapse > m_it.value().TimeMax) m_it.value().TimeMax = m_elapse;
-        if(m_elapse < m_it.value().TimeMin) m_it.value().TimeMin = m_elapse;
+        if (m_elapse > m_it.value().TimeMax) m_it.value().TimeMax = m_elapse;
+        if (m_elapse < m_it.value().TimeMin) m_it.value().TimeMin = m_elapse;
 
-        if(!SKGTraces::m_SKGPerfoPathMethode.empty() && SKGTraces::m_SKGPerfoPathMethode.top() == m_mame) {
+        if (!SKGTraces::m_SKGPerfoPathMethode.empty() && SKGTraces::m_SKGPerfoPathMethode.top() == m_mame) {
 
             //Remove current methode from stack
             SKGTraces::m_SKGPerfoPathMethode.pop();
 
             //Get previous methode name
-            if(!SKGTraces::m_SKGPerfoPathMethode.empty()) {
+            if (!SKGTraces::m_SKGPerfoPathMethode.empty()) {
                 QString previousMethode = SKGTraces::m_SKGPerfoPathMethode.top();
 
                 //Searching the key in the map
                 m_it = SKGTraces::m_SKGPerfoMethode.find(previousMethode);
-                if(m_it != SKGTraces::m_SKGPerfoMethode.end()) {
+                if (m_it != SKGTraces::m_SKGPerfoMethode.end()) {
                     m_it.value().TimePropre -= m_elapse;
                 }
             }
@@ -164,7 +164,7 @@ void SKGTraces::dumpProfilingStatistics()
     QStringList dump = getProfilingStatistics();
 
     int nbl = dump.count();
-    for(int i = 0; i < nbl; ++i) {
+    for (int i = 0; i < nbl; ++i) {
         SKGTRACE << dump[i] << endl;
     }
 }
@@ -172,33 +172,33 @@ void SKGTraces::dumpProfilingStatistics()
 QStringList SKGTraces::getProfilingStatistics()
 {
     QStringList output;
-    if(SKGPerfo) {
+    if (SKGPerfo) {
         output.push_back("method , nb call , millisecondes , average , min , max , own time , average own time");
 
         SKGPerfoMap SKGPerfoMethodeCopy = m_SKGPerfoMethode;
-        while(!SKGPerfoMethodeCopy.empty()) {
+        while (!SKGPerfoMethodeCopy.empty()) {
 
             //Recheche du temps propre maximal
             double maxtime = -1;
             SKGPerfoMapIterator max;
             SKGPerfoMapIterator it2;
-            for(it2 = SKGPerfoMethodeCopy.begin() ; it2 != SKGPerfoMethodeCopy.end(); ++it2) {
-                if(it2.value().TimePropre > maxtime) {
+            for (it2 = SKGPerfoMethodeCopy.begin() ; it2 != SKGPerfoMethodeCopy.end(); ++it2) {
+                if (it2.value().TimePropre > maxtime) {
                     maxtime = it2.value().TimePropre;
                     max = it2;
                 }
             }
 
             //dump max
-            if(maxtime != -1) {
+            if (maxtime != -1) {
                 output.push_back(max.key()
-                                 + " , " + SKGServices::intToString(max.value().NbCall)
-                                 + " , " + SKGServices::doubleToString(max.value().Time)
-                                 + " , " + SKGServices::doubleToString((max.value().Time) / (static_cast<double>(max.value().NbCall)))
-                                 + " , " + SKGServices::doubleToString(max.value().TimeMin)
-                                 + " , " + SKGServices::doubleToString(max.value().TimeMax)
-                                 + " , " + SKGServices::doubleToString(max.value().TimePropre)
-                                 + " , " + SKGServices::doubleToString((max.value().TimePropre) / (static_cast<double>(max.value().NbCall))));
+                                 % " , " % SKGServices::intToString(max.value().NbCall)
+                                 % " , " % SKGServices::doubleToString(max.value().Time)
+                                 % " , " % SKGServices::doubleToString((max.value().Time) / (static_cast<double>(max.value().NbCall)))
+                                 % " , " % SKGServices::doubleToString(max.value().TimeMin)
+                                 % " , " % SKGServices::doubleToString(max.value().TimeMax)
+                                 % " , " % SKGServices::doubleToString(max.value().TimePropre)
+                                 % " , " % SKGServices::doubleToString((max.value().TimePropre) / (static_cast<double>(max.value().NbCall))));
 
                 //Remove it
                 SKGPerfoMethodeCopy.erase(max);
