@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -37,7 +37,7 @@
  *   SKGBEGINTRANSACTION(Your_SKGDocument, "The_Name_Of_The_Transaction", err);
  *
  *  //Check the error
- *  if(err.isSucceeded())
+ *  if(!err)
  *  {
  *   //You code here
  *   //At the end the err variable must contain the result of your operation
@@ -50,6 +50,12 @@
 #define SKGBEGINTRANSACTION(Document, Name, Error) \
     SKGTransactionMng __SKGCurrentTransaction__(&Document, Name, &Error);
 
+/**
+ * @def SKGBEGINLIGHTTRANSACTION(Document, Name, Error)
+ * Macro to start a new light transaction (without views computation)
+ */
+#define SKGBEGINLIGHTTRANSACTION(Document, Name, Error) \
+    SKGTransactionMng __SKGCurrentTransaction__(&Document, Name, &Error, 1, false);
 /**
  * @def SKGBEGINPROGRESSTRANSACTION(Document, Name, Error)
  * Macro to start a new transaction
@@ -63,7 +69,7 @@
  *   SKGBEGINPROGRESSTRANSACTION(Your_SKGDocument, "The_Name_Of_The_Transaction", err, 5);
  *
  *  //Check the error
- *  if(err.isSucceeded())
+ *  if(!err)
  *  {
  *   //You code here
  *   //At the end the err variable must contain the result of your operation
@@ -82,6 +88,13 @@
 #define SKGBEGINPROGRESSTRANSACTION(Document, Name, Error, Nb) \
     SKGTransactionMng __SKGCurrentTransaction__(&Document, Name, &Error, Nb);
 
+/**
+ * @def SKGBEGINLIGHTPROGRESSTRANSACTION(Document, Name, Error)
+ * Macro to start a new light transaction (without views computation)
+ */
+#define SKGBEGINLIGHTPROGRESSTRANSACTION(Document, Name, Error, Nb) \
+    SKGTransactionMng __SKGCurrentTransaction__(&Document, Name, &Error, Nb, false);
+
 class SKGError;
 class SKGDocument;
 
@@ -99,10 +112,11 @@ public:
      * @param iName The message of the transaction
      * @param iError A pointer of the error object of the calling scope
      * @param iNbStep the number of step in this transaction.
+     * @param iRefreshViews at the end of the transaction, computed views will be recomputed.
      * It's used to call the progress callback.
      * @see The SKGError
      */
-    SKGTransactionMng(SKGDocument* iDocument, const QString& iName, SKGError* iError, int iNbStep = 1);
+    SKGTransactionMng(SKGDocument* iDocument, const QString& iName, SKGError* iError, int iNbStep = 1, bool iRefreshViews = true);
 
     /**
      * Destructor
