@@ -53,7 +53,7 @@ int main(int argc, char** argv)
                      0,
                      ki18nc("The name of the application", "Skrooge"),
                      VER,
-                     ki18nc("The description of the application", "Personal finance management tool for KDE4, with the aim of being highly intuitive, while providing powerful functions such as reporting (including graphics), persistent Undo/Redo, encryption, and much more..."),
+                     ki18nc("The description of the application", "Personal finances management made simple"),
                      KAboutData::License_GPL_V3,
                      ki18nc("Fullname", "(c) 2007-%1 Stephane MANKOWSKI & Guillaume DE BURE").subs(QDate::currentDate().toString("yyyy")),
                      KLocalizedString(),
